@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8274 $
-## |  Last changed: $Date: 2024-09-26 11:33:59 +0200 (Do, 26 Sep 2024) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #' @include class_dictionary.R
 #' @include f_core_constants.R
@@ -285,6 +281,9 @@ ParameterSet <- R6::R6Class("ParameterSet",
         isUndefinedParameter = function(parameterName) {
             return(self$.getParameterType(parameterName) == C_PARAM_TYPE_UNKNOWN)
         },
+        isNotApplicableParameter = function(parameterName) {
+            return(self$.getParameterType(parameterName) == C_PARAM_NOT_APPLICABLE)
+        },
         .getInputParameters = function() {
             params <- self$.getParametersOfOneGroup(c(C_PARAM_USER_DEFINED, C_PARAM_DEFAULT_VALUE))
             return(params)
@@ -335,6 +334,7 @@ ParameterSet <- R6::R6Class("ParameterSet",
             } else {
                 parameterNames <- names(self$.parameterTypes[which(self$.parameterTypes %in% parameterType)])
             }
+            
             parametersToShow <- self$.getParametersToShow()
             if (is.null(parametersToShow) || length(parametersToShow) == 0) {
                 return(parameterNames)
@@ -375,7 +375,8 @@ ParameterSet <- R6::R6Class("ParameterSet",
             if (!is.null(showType) && showType == 2) {
                 self$.cat("Technical developer summary of the ", self$.toString(), " object (",
                     methods::classLabel(class(self)), "):\n\n",
-                    sep = "", heading = 1,
+                    sep = "", 
+                    heading = 1,
                     consoleOutputEnabled = consoleOutputEnabled
                 )
                 self$.showAllParameters(consoleOutputEnabled = consoleOutputEnabled)
@@ -471,8 +472,10 @@ ParameterSet <- R6::R6Class("ParameterSet",
                 }
             ) 
         },
-        .showParameterSingle = function(param,
-                parameterName, ...,
+        .showParameterSingle = function(
+                param,
+                parameterName, 
+                ...,
                 category = NULL,
                 showParameterType = FALSE,
                 consoleOutputEnabled = TRUE) {
@@ -566,7 +569,6 @@ ParameterSet <- R6::R6Class("ParameterSet",
                 parameterName <- substr(parameterName, index + 1, nchar(parameterName))
                 obj <- base::get(objectName, envir = self)
                 paramValue <- base::get(parameterName, envir = obj)
-                #paramValue <- self[[objectName]][[parameterName]]
             
                 if (objectName == ".closedTestResults" && parameterName == "rejected") {
                     paramValueLogical <- as.logical(paramValue)
@@ -906,6 +908,7 @@ ParameterSet <- R6::R6Class("ParameterSet",
     parameterNames <- parameterNames[!(parameterNames %in% c(
         "accrualTime", 
         "accrualIntensity",
+        "accrualIntensityRelative",
         "plannedSubjects", 
         "plannedEvents",
         "minNumberOfSubjectsPerStage", 
@@ -917,7 +920,9 @@ ParameterSet <- R6::R6Class("ParameterSet",
         "adaptations",
         "adjustedStageWisePValues", 
         "overallAdjustedTestStatistics",
-        "plannedCalendarTime"
+        "plannedCalendarTime",
+        "doseLevels",
+        "stDev"
     ))]
 
     if (!is.null(parameterSet[[".piecewiseSurvivalTime"]]) &&
@@ -979,7 +984,7 @@ ParameterSet <- R6::R6Class("ParameterSet",
     if (parameterName %in% c("adjustedStageWisePValues", "overallAdjustedTestStatistics")) {
         return(NULL)
     }
-
+    
     if (!is.matrix(parameterValues)) {
         if (length(parameterValues) == 1) {
             return(rep(parameterValues, numberOfVariants * numberOfStages))
@@ -997,9 +1002,12 @@ ParameterSet <- R6::R6Class("ParameterSet",
 
         if (length(parameterValues) == numberOfStages &&
                 parameterName %in% c(
-                    "plannedEvents", "plannedSubjects",
-                    "minNumberOfEventsPerStage", "maxNumberOfEventsPerStage",
-                    "minNumberOfSubjectsPerStage", "maxNumberOfSubjectsPerStage",
+                    "plannedEvents", 
+                    "plannedSubjects",
+                    "minNumberOfEventsPerStage", 
+                    "maxNumberOfEventsPerStage",
+                    "minNumberOfSubjectsPerStage", 
+                    "maxNumberOfSubjectsPerStage",
                     "allocationRatioPlanned"
                 )) {
             values <- c()
@@ -1010,13 +1018,24 @@ ParameterSet <- R6::R6Class("ParameterSet",
         }
 
         if (parameterName %in% c(
-                "accrualTime", "accrualIntensity",
-                "plannedEvents", "plannedSubjects",
-                "minNumberOfEventsPerStage", "maxNumberOfEventsPerStage",
-                "minNumberOfSubjectsPerStage", "maxNumberOfSubjectsPerStage",
-                "piecewiseSurvivalTime", "lambda2"
-            )) {
-            return(NULL)
+                "accrualTime", 
+                "accrualIntensity",
+                "plannedEvents", 
+                "plannedSubjects",
+                "minNumberOfEventsPerStage", 
+                "maxNumberOfEventsPerStage",
+                "minNumberOfSubjectsPerStage", 
+                "maxNumberOfSubjectsPerStage",
+                "piecewiseSurvivalTime", 
+                "lambda2",
+                "stDev"
+                )) {
+
+            if (parameterName == "stDev" && length(unique(parameterValues)) == 1) {
+                return(parameterValues[1])
+            }
+            
+            return(paste(parameterValues, collapse = ", "))
         }
 
         stop(
@@ -1146,7 +1165,8 @@ ParameterSet <- R6::R6Class("ParameterSet",
     for (parameterName in parameterNames) {
         tryCatch(
             {
-                if (!(parameterName %in% c("stages", "adaptations", "effectList", "plannedCalendarTime")) &&
+                if (!(parameterName %in% c("stages", "adaptations", "effectList", 
+                            "doseLevels", "plannedCalendarTime")) && 
                         !grepl("Function$", parameterName) &&
                         (is.null(variedParameter) || parameterName != variedParameter)) {
                     columnValues <- .getDataFrameColumnValues(
@@ -1154,10 +1174,16 @@ ParameterSet <- R6::R6Class("ParameterSet",
                         numberOfVariants, numberOfStages,
                         includeAllParameters, mandatoryParameterNames
                     )
+                    
                     if (!is.null(columnValues)) {
                         columnCaption <- parameterSet$.getDataFrameColumnCaption(
                             parameterName, niceColumnNamesEnabled
                         )
+                        
+                        if (parameterName == "stDev" && length(columnValues) == 2) {
+                            columnValues <- paste(columnValues, collapse = ", ")
+                        }
+                        
                         dataFrame[[columnCaption]] <- columnValues
                         if (returnParametersAsCharacter) {
                             parameterSet$.formatDataFrameParametersAsCharacter(
@@ -1314,16 +1340,17 @@ ParameterSet <- R6::R6Class("ParameterSet",
         parametersToIgnore <- intersect(parametersToIgnore, parameterNames)
     }
 
-    if (parameterSet$.getParameterType("hazardRatio") == C_PARAM_GENERATED &&
+    if (parameterSet$isGeneratedParameter("hazardRatio") &&
             !is.null(parameterSet[[".piecewiseSurvivalTime"]]) &&
             isTRUE(parameterSet$.piecewiseSurvivalTime$piecewiseSurvivalEnabled)) {
         parametersToIgnore <- c(parametersToIgnore, "hazardRatio")
     }
 
     if (!inherits(parameterSet, "AccrualTime")) {
-        accrualTime <- parameterSet[["accrualTime"]]
+        accrualTime <- parameterSet[[".accrualTime"]]
         if (!is.null(accrualTime) && length(accrualTime) > 1) {
-            parametersToIgnore <- c(parametersToIgnore, c("accrualTime", "accrualIntensity"))
+            parametersToIgnore <- c(parametersToIgnore, 
+                c("accrualTime", "accrualIntensity", "accrualIntensityRelative"))
         }
     }
 
@@ -1430,13 +1457,7 @@ print.FieldSet <- function(x, ..., markdown = NA) {
             return(knitr::asis_output(result))
         }
         
-        attr(x, "markdown") <- TRUE
-        queue <- attr(x, "queue")
-        if (is.null(queue)) {
-            queue <- list()
-        }
-        queue[[length(queue) + 1]] <- x
-        attr(x, "queue") <- queue
+        .addObjectToPipeOperatorQueue(x)
         return(invisible(x))
     }
     
@@ -1465,8 +1486,13 @@ print.FieldSet <- function(x, ..., markdown = NA) {
 #'
 #' @keywords internal
 #'
-as.data.frame.ParameterSet <- function(x, row.names = NULL,
-        optional = FALSE, niceColumnNamesEnabled = FALSE, includeAllParameters = FALSE, ...) {
+as.data.frame.ParameterSet <- function(
+        x, 
+        row.names = NULL,
+        optional = FALSE, 
+        ..., 
+        niceColumnNamesEnabled = FALSE, 
+        includeAllParameters = FALSE) {
     .warnInCaseOfUnknownArguments(functionName = "as.data.frame", ...)
 
     return(.getAsDataFrame(
@@ -1686,24 +1712,35 @@ print.ParameterSet <- function(x, ..., markdown = NA) {
     if (is.na(markdown)) {
         markdown <- .isMarkdownEnabled("print")
     }
-
+    
+    showStatistics <- NULL
+    if (inherits(x, "SimulationResults")) {
+        showStatistics <- .getOptionalArgument("showStatistics", ...)
+        if (!is.null(showStatistics)) {
+            .assertIsSingleLogical(showStatistics, "showStatistics")
+        }
+    }
+    
     if (isTRUE(markdown)) {
         if (.isPrintCall(sysCalls)) {
-            result <- paste0(utils::capture.output(x$.catMarkdownText()), collapse = "\n")
+            if (!is.null(showStatistics)) {
+                result <- paste0(utils::capture.output(
+                    x$.catMarkdownText(showStatistics = showStatistics)), collapse = "\n")
+            } else {
+                result <- paste0(utils::capture.output(x$.catMarkdownText()), collapse = "\n")
+            }
             return(knitr::asis_output(result))
         }
         
-        attr(x, "markdown") <- TRUE
-        queue <- attr(x, "queue")
-        if (is.null(queue)) {
-            queue <- list()
-        }
-        queue[[length(queue) + 1]] <- x
-        attr(x, "queue") <- queue
+        .addObjectToPipeOperatorQueue(x)
         return(invisible(x))
     }
     
-    x$show()
+    if (!is.null(showStatistics)) {
+        x$show(showStatistics = showStatistics)
+    } else {
+        x$show()
+    }
     return(invisible(x))
 }
 
@@ -2090,7 +2127,7 @@ kable.ParameterSet <- function(x, ...) {
     
     lastWarningTime <- getOption("rpact.deprecated.message.time.function.kable")
     if (is.null(lastWarningTime) || difftime(Sys.time(), lastWarningTime, units = "hours") > 8) {
-        options("rpact.deprecated.message.time.function.kable" = Sys.time())
+        base::options("rpact.deprecated.message.time.function.kable" = Sys.time())
         .Deprecated(new = "",  
             msg = paste0("Manual use of kable() for rpact result objects is no longer needed, ",
                 "as the formatting and display will be handled automatically by the rpact package"),
