@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8629 $
-## |  Last changed: $Date: 2025-03-24 09:50:39 +0100 (Mo, 24 Mrz 2025) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 
 #' @include f_core_constants.R
@@ -443,7 +439,17 @@ TrialDesignFisher <- R6::R6Class("TrialDesignFisher",
             self$.setParameterType("seed", C_PARAM_NOT_APPLICABLE)
             self$.initStages()
         },
-        hasChanged = function(kMax, alpha, sided, method, informationRates, alpha0Vec, userAlphaSpending, bindingFutility) {
+        hasChanged = function(
+                ...,
+                kMax, 
+                alpha, 
+                sided, 
+                method, 
+                informationRates, 
+                alpha0Vec, 
+                alpha0Scale, 
+                userAlphaSpending, 
+                bindingFutility) {
             informationRatesTemp <- informationRates
             if (any(is.na(informationRatesTemp))) {
                 informationRatesTemp <- .getInformationRatesDefault(kMax)
@@ -452,7 +458,9 @@ TrialDesignFisher <- R6::R6Class("TrialDesignFisher",
             if (any(is.na(alpha0VecTemp))) {
                 alpha0VecTemp <- rep(C_FUTILITY_BOUNDS_DEFAULT, kMax - 1)
             }
-
+            if (!isTRUE(all.equal(alpha0Scale, self$alpha0Scale))) {
+                return(TRUE)
+            }
             if (!isTRUE(all.equal(kMax, self$kMax))) {
                 return(TRUE)
             }
@@ -539,6 +547,8 @@ TrialDesignFisher <- R6::R6Class("TrialDesignFisher",
 #' @template field_betaSpent
 #' @template field_typeBetaSpending
 #' @template field_userBetaSpending
+#' @template field_efficacyStops
+#' @template field_futilityStops
 #' @template field_power
 #' @template field_twoSidedPower
 #' @template field_constantBoundsHP
@@ -577,6 +587,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
         betaSpent = NULL,
         typeBetaSpending = NULL,
         userBetaSpending = NULL,
+        efficacyStops = NULL,
+        futilityStops = NULL,
         power = NULL,
         twoSidedPower = NULL,
         constantBoundsHP = NULL,
@@ -598,6 +610,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
                 gammaB = NA_real_,
                 typeBetaSpending = C_TYPE_OF_DESIGN_BS_NONE,
                 userBetaSpending = NA_real_,
+                efficacyStops = NA,
+                futilityStops = NA,
                 power = NA_real_,
                 twoSidedPower = C_TWO_SIDED_POWER_DEFAULT,
                 constantBoundsHP = NA_real_,
@@ -616,6 +630,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
             self$gammaB <- gammaB
             self$typeBetaSpending <- typeBetaSpending
             self$userBetaSpending <- userBetaSpending
+            self$efficacyStops <- efficacyStops
+            self$futilityStops <- futilityStops
             self$power <- power
             self$twoSidedPower <- twoSidedPower
             self$constantBoundsHP <- constantBoundsHP
@@ -630,6 +646,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
             self$.setParameterType("delayedInformation", C_PARAM_NOT_APPLICABLE)
             self$.setParameterType("decisionCriticalValues", C_PARAM_NOT_APPLICABLE)
             self$.setParameterType("reversalProbabilities", C_PARAM_NOT_APPLICABLE)
+            self$.setParameterType("efficacyStops", C_PARAM_NOT_APPLICABLE)
+            self$.setParameterType("futilityStops", C_PARAM_NOT_APPLICABLE)
         },
         .formatComparisonResult = function(x) {
             if (is.null(x) || length(x) == 0 || !is.numeric(x)) {
@@ -646,7 +664,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
                 name, "_old = ", .arrayToString(self$.formatComparisonResult(oldValue)), " (", .getClassName(oldValue), ")"
             ))
         },
-        hasChanged = function(...,
+        hasChanged = function(
+                ...,
                 kMax,
                 alpha,
                 beta,
@@ -657,6 +676,7 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
                 deltaPT0,
                 informationRates,
                 futilityBounds,
+                futilityBoundsScale,
                 optimizationCriterion,
                 typeBetaSpending,
                 gammaA,
@@ -676,7 +696,9 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
             if (any(is.na(futilityBoundsTemp))) {
                 futilityBoundsTemp <- rep(C_FUTILITY_BOUNDS_DEFAULT, kMax - 1)
             }
-
+            if (!isTRUE(all.equal(futilityBoundsScale, self$futilityBoundsScale))) {
+                return(self$.pasteComparisonResult("futilityBoundsScale", futilityBoundsScale, self$futilityBoundsScale))
+            }
             if (!isTRUE(all.equal(kMax, self$kMax))) {
                 return(self$.pasteComparisonResult("kMax", kMax, self$kMax))
             }
@@ -826,6 +848,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
                 "betaSpent",
                 "typeBetaSpending",
                 "userBetaSpending",
+                "efficacyStops",
+                "futilityStops",
                 "criticalValues",
                 "stageLevels",
                 "decisionCriticalValues",
@@ -867,6 +891,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
 #' @template field_betaSpent
 #' @template field_typeBetaSpending
 #' @template field_userBetaSpending
+#' @template field_efficacyStops
+#' @template field_futilityStops
 #' @template field_power
 #' @template field_twoSidedPower
 #' @template field_constantBoundsHP
@@ -1016,7 +1042,7 @@ TrialDesignConditionalDunnett <- R6::R6Class("TrialDesignConditionalDunnett",
 #' p-values only in the design definition, and not in the analysis call.\cr
 #' See \code{\link[=getClosedConditionalDunnettTestResults]{getClosedConditionalDunnettTestResults()}}
 #' for an example and Koenig et al. (2008) and
-#' Wassmer & Brannath (2016), chapter 11 for details of the test procedure.
+#' Wassmer & Brannath (2025), chapter 11 for details of the test procedure.
 #'
 #' @template return_object_trial_design
 #' @template how_to_get_help_for_generics
@@ -1032,7 +1058,7 @@ getDesignConditionalDunnett <- function(alpha = 0.025, # C_ALPHA_DEFAULT
         directionUpper = NA) {
     .assertIsValidAlpha(alpha)
     .assertIsSingleNumber(informationAtInterim, "informationAtInterim")
-    .assertIsInOpenInterval(informationAtInterim, "informationAtInterim", 0, 1)
+    .assertIsInOpenInterval(informationAtInterim, "informationAtInterim", lower = 0, upper = 1)
     .assertIsSingleLogical(directionUpper, "directionUpper", naAllowed = TRUE)
     design <- TrialDesignConditionalDunnett$new(
         alpha = alpha,
