@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8385 $
-## |  Last changed: $Date: 2024-11-13 11:30:34 +0100 (Mi, 13 Nov 2024) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 .getRecalculatedInformationRates <- function(dataInput,
         maxInformation,
@@ -118,7 +114,8 @@ getObservedInformationRates <- function(dataInput,
     .assertIsSingleNumber(maxInformation, "maxInformation")
     .assertIsInOpenInterval(
         maxInformation,
-        "maxInformation", 0, NULL
+        "maxInformation", 
+        lower = 0, upper = NULL
     )
 
     information <- .getRecalculatedInformationRates(dataInput, maxInformation, stage = stage)
