@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8624 $
-## |  Last changed: $Date: 2025-03-21 13:24:59 +0100 (Fr, 21 Mrz 2025) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #' @include f_core_utilities.R
 NULL
@@ -54,12 +50,12 @@ NULL
         }
         return(.getAnalysisResultsMeansMultiArm(
             design = design,
-            dataInput = dataInput, 
+            dataInput = dataInput,
             intersectionTest = intersectionTest,
-            directionUpper = directionUpper, 
+            directionUpper = directionUpper,
             thetaH0 = thetaH0,
-            nPlanned = nPlanned, 
-            stage = stage, 
+            nPlanned = nPlanned,
+            stage = stage,
             ...
         ))
     }
@@ -70,12 +66,12 @@ NULL
         }
         return(.getAnalysisResultsRatesMultiArm(
             design = design,
-            dataInput = dataInput, 
+            dataInput = dataInput,
             intersectionTest = intersectionTest,
-            directionUpper = directionUpper, 
+            directionUpper = directionUpper,
             thetaH0 = thetaH0,
-            nPlanned = nPlanned, 
-            stage = stage, 
+            nPlanned = nPlanned,
+            stage = stage,
             ...
         ))
     }
@@ -86,18 +82,17 @@ NULL
         }
         return(.getAnalysisResultsSurvivalMultiArm(
             design = design,
-            dataInput = dataInput, 
+            dataInput = dataInput,
             intersectionTest = intersectionTest,
-            directionUpper = directionUpper, 
+            directionUpper = directionUpper,
             thetaH0 = thetaH0,
-            nPlanned = nPlanned, 
-            stage = stage, 
+            nPlanned = nPlanned,
+            stage = stage,
             ...
         ))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type ",
-        "'", .getClassName(dataInput), "' is not implemented yet")
+    .fireDataInputNotSupportedException(dataInput)
 }
 
 #'
@@ -107,9 +102,9 @@ NULL
 #' @noRd
 #'
 .getStageResultsMultiArm <- function(
-        design, 
-        dataInput, 
-        ..., 
+        design,
+        dataInput,
+        ...,
         directionUpper = NA) {
     .assertIsTrialDesignInverseNormalOrFisherOrConditionalDunnett(design)
     stage <- .getStageFromOptionalArguments(..., dataInput = dataInput, design = design)
@@ -118,45 +113,46 @@ NULL
 
     if (dataInput$isDatasetMeans()) {
         return(.getStageResultsMeansMultiArm(
-            design = design, 
-            dataInput = dataInput, 
-            directionUpper = directionUpper, 
-            userFunctionCallEnabled = TRUE, 
-            ...))
+            design = design,
+            dataInput = dataInput,
+            directionUpper = directionUpper,
+            userFunctionCallEnabled = TRUE,
+            ...
+        ))
     }
 
     if (dataInput$isDatasetRates()) {
         return(.getStageResultsRatesMultiArm(
-            design = design, 
-            dataInput = dataInput, 
-            directionUpper = directionUpper, 
-            userFunctionCallEnabled = TRUE, 
-            ...))
+            design = design,
+            dataInput = dataInput,
+            directionUpper = directionUpper,
+            userFunctionCallEnabled = TRUE,
+            ...
+        ))
     }
 
     if (dataInput$isDatasetSurvival()) {
         return(.getStageResultsSurvivalMultiArm(
-            design = design, 
-            dataInput = dataInput, 
-            directionUpper = directionUpper, 
-            userFunctionCallEnabled = TRUE, 
-            ...))
+            design = design,
+            dataInput = dataInput,
+            directionUpper = directionUpper,
+            userFunctionCallEnabled = TRUE,
+            ...
+        ))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type ",
-        "'", .getClassName(dataInput), "' is not supported")
+    .fireDataInputNotSupportedException(dataInput)
 }
 
 #'
 #' Get Repeated Confidence Intervals for multi-arm case
-#' Calculates and returns the lower and upper limit of the repeated 
+#' Calculates and returns the lower and upper limit of the repeated
 #' confidence intervals of the trial for multi-arm designs.
 #'
 #' @noRd
 #'
-.getRepeatedConfidenceIntervalsMultiArm <- function(
-        design, 
-        dataInput, 
+.getRepeatedConfidenceIntervalsMultiArm <- function(design,
+        dataInput,
         ...) {
     .assertIsTrialDesignInverseNormalOrFisherOrConditionalDunnett(design)
     stage <- .getStageFromOptionalArguments(..., dataInput = dataInput, design = design)
@@ -165,29 +161,29 @@ NULL
 
     if (dataInput$isDatasetMeans()) {
         return(.getRepeatedConfidenceIntervalsMeansMultiArm(
-            design = design, 
-            dataInput = dataInput, 
+            design = design,
+            dataInput = dataInput,
             ...
         ))
     }
 
     if (dataInput$isDatasetRates()) {
         return(.getRepeatedConfidenceIntervalsRatesMultiArm(
-            design = design, 
-            dataInput = dataInput, 
+            design = design,
+            dataInput = dataInput,
             ...
         ))
     }
 
     if (dataInput$isDatasetSurvival()) {
         return(.getRepeatedConfidenceIntervalsSurvivalMultiArm(
-            design = design, 
-            dataInput = dataInput, 
+            design = design,
+            dataInput = dataInput,
             ...
         ))
     }
 
-    stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '", .getClassName(dataInput), "' is not implemented yet")
+    .fireDataInputNotSupportedException(dataInput)
 }
 
 #'
@@ -212,8 +208,8 @@ NULL
 
         return(.getConditionalPowerMeansMultiArm(
             stageResults = stageResults,
-            nPlanned = nPlanned, 
-            allocationRatioPlanned = allocationRatioPlanned, 
+            nPlanned = nPlanned,
+            allocationRatioPlanned = allocationRatioPlanned,
             ...
         ))
     }
@@ -221,8 +217,8 @@ NULL
     if (stageResults$isDatasetRates()) {
         return(.getConditionalPowerRatesMultiArm(
             stageResults = stageResults,
-            nPlanned = nPlanned, 
-            allocationRatioPlanned = allocationRatioPlanned, 
+            nPlanned = nPlanned,
+            allocationRatioPlanned = allocationRatioPlanned,
             ...
         ))
     }
@@ -230,16 +226,13 @@ NULL
     if (stageResults$isDatasetSurvival()) {
         return(.getConditionalPowerSurvivalMultiArm(
             stageResults = stageResults,
-            nPlanned = nPlanned, 
-            allocationRatioPlanned = allocationRatioPlanned, 
+            nPlanned = nPlanned,
+            allocationRatioPlanned = allocationRatioPlanned,
             ...
         ))
     }
 
-    stop(
-        C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '",
-        .getClassName(stageResults$.dataInput), "' is not implemented yet"
-    )
+    .fireDataInputNotSupportedException(stageResults$getDataInput())
 }
 
 .getIndicesOfClosedHypothesesSystem <- function(gMax) {
@@ -265,7 +258,7 @@ NULL
     gMax <- stageResults$getGMax()
     kMax <- design$kMax
     indices <- .getIndicesOfClosedHypothesesSystem(gMax = gMax)
-    
+
     adjustedStageWisePValues <- matrix(NA_real_, nrow = 2^gMax - 1, ncol = kMax)
     adjustedOverallPValues <- matrix(NA_real_, nrow = 2^gMax - 1, ncol = kMax)
 
@@ -658,28 +651,28 @@ getClosedCombinationTestResults <- function(stageResults) {
                         alpha <- (lower + upper) / 2
                         if (.isTrialDesignFisher(design)) {
                             designAlpha <- .getDesignFisher(
-                                kMax = kMax, 
+                                kMax = kMax,
                                 alpha = alpha,
-                                method = design$method, 
+                                method = design$method,
                                 alpha0Vec = design$alpha0Vec,
-                                sided = design$sided, 
+                                sided = design$sided,
                                 bindingFutility = design$bindingFutility,
                                 informationRates = design$informationRates
                             )
                         } else {
                             designAlpha <- .getDesignInverseNormal(
                                 kMax = kMax,
-                                alpha = alpha, 
-                                typeOfDesign = typeOfDesign, 
+                                alpha = alpha,
+                                typeOfDesign = typeOfDesign,
                                 deltaWT = deltaWT,
-                                typeBetaSpending = typeBetaSpending, 
+                                typeBetaSpending = typeBetaSpending,
                                 gammaB = design$gammaB,
-                                deltaPT0 = design$deltaPT0, 
-                                deltaPT1 = design$deltaPT1, 
+                                deltaPT0 = design$deltaPT0,
+                                deltaPT1 = design$deltaPT1,
                                 beta = design$beta,
-                                gammaA = design$gammaA, 
+                                gammaA = design$gammaA,
                                 futilityBounds = design$futilityBounds,
-                                sided = design$sided, 
+                                sided = design$sided,
                                 bindingFutility = design$bindingFutility,
                                 informationRates = design$informationRates
                             )
@@ -717,7 +710,7 @@ getClosedCombinationTestResults <- function(stageResults) {
 #' @details
 #' For performing the conditional Dunnett test the design must be defined through the function
 #' \code{\link[=getDesignConditionalDunnett]{getDesignConditionalDunnett()}}.\cr
-#' See Koenig et al. (2008) and Wassmer & Brannath (2016), chapter 11 for details of the test procedure.
+#' See Koenig et al. (2008) and Wassmer & Brannath (2025), chapter 11 for details of the test procedure.
 #'
 #' @template return_object_closed_combination_test_results
 #' @template how_to_get_help_for_generics
@@ -726,16 +719,15 @@ getClosedCombinationTestResults <- function(stageResults) {
 #'
 #' @export
 #'
-getClosedConditionalDunnettTestResults <- function(
-        stageResults, 
-        ..., 
+getClosedConditionalDunnettTestResults <- function(stageResults,
+        ...,
         stage = stageResults$stage) {
-        
     .assertIsStageResultsMultiArm(stageResults)
     .assertIsValidStage(stage, kMax = 2)
     .warnInCaseOfUnknownArguments(
-        functionName = "getClosedConditionalDunnettTestResults", 
-        ignore = c("design"), ...)
+        functionName = "getClosedConditionalDunnettTestResults",
+        ignore = c("design"), ...
+    )
 
     design <- stageResults$.design
     if (!is.null(list(...)[["design"]])) {
@@ -744,9 +736,10 @@ getClosedConditionalDunnettTestResults <- function(
     .assertIsTrialDesignConditionalDunnett(design)
 
     result <- .getClosedConditionalDunnettTestResults(
-        stageResults = stageResults, 
-        design = design, 
-        stage = stage)
+        stageResults = stageResults,
+        design = design,
+        stage = stage
+    )
     return(ClosedCombinationTestResults$new(
         .design = result$.design,
         .enrichment = grepl("Enrichment", .getClassName(stageResults)),
@@ -790,7 +783,7 @@ getClosedConditionalDunnettTestResults <- function(
         if (stage == 2) {
             frac2 <- stageResults$.dataInput$sampleSizes[stageResults$.dataInput$stages == 2 &
                 stageResults$.dataInput$groups <= gMax] /
-               (stageResults$.dataInput$sampleSizes[stageResults$.dataInput$stages == 2 &
+                (stageResults$.dataInput$sampleSizes[stageResults$.dataInput$stages == 2 &
                     stageResults$.dataInput$groups <= gMax] +
                     stageResults$.dataInput$sampleSizes[stageResults$.dataInput$stages == 2 &
                         stageResults$.dataInput$groups == (gMax + 1)])
@@ -966,8 +959,8 @@ getClosedConditionalDunnettTestResults <- function(
         innerProduct <- 1
         for (g in (1:gMax)) {
             innerProduct <- innerProduct * stats::pnorm(((crit -
-              sqrt(informationAtInterim) * signedTestStatistics[treatmentArm, 1] +
-              sqrt(1 - informationAtInterim) * sqrt(frac1[g]) * x)) /
+                sqrt(informationAtInterim) * signedTestStatistics[treatmentArm, 1] +
+                sqrt(1 - informationAtInterim) * sqrt(frac1[g]) * x)) /
                 sqrt((1 - informationAtInterim) * (1 - frac1[g])))
         }
         return(innerProduct * dnorm(x))
@@ -983,9 +976,9 @@ getClosedConditionalDunnettTestResults <- function(
                     if (!is.na(stageResults$overallTestStatistics[g, 2])) {
                         innerProduct <- innerProduct *
                             stats::pnorm(((maxOverallTestStatistic -
-                               sqrt(informationAtInterim) * signedTestStatistics[treatmentArm, 1] +
-                               sqrt(1 - informationAtInterim) * sqrt(frac2[g]) * x)) /
-                               sqrt((1 - informationAtInterim) * (1 - frac2[g])))
+                                sqrt(informationAtInterim) * signedTestStatistics[treatmentArm, 1] +
+                                sqrt(1 - informationAtInterim) * sqrt(frac2[g]) * x)) /
+                                sqrt((1 - informationAtInterim) * (1 - frac2[g])))
                     }
                 }
                 return(innerProduct * dnorm(x))
@@ -1007,11 +1000,11 @@ getClosedConditionalDunnettTestResults <- function(
         }
     }
 
-    # cat("upper = ", stageResults$directionUpper , ", gMax = ", gMax, 
-    #     ", selected = ", selected, ", treatmentArm = ", treatmentArm, 
+    # cat("upper = ", stageResults$directionUpper , ", gMax = ", gMax,
+    #     ", selected = ", selected, ", treatmentArm = ", treatmentArm,
     #     ", conditionalErrorRate = ", conditionalErrorRate,
     #     ", secondStagePValues = ", secondStagePValues, "\n")
-    
+
     return(secondStagePValues <= conditionalErrorRate)
 }
 
@@ -1020,30 +1013,29 @@ getClosedConditionalDunnettTestResults <- function(
 #'
 #' @noRd
 #'
-.getConditionalRejectionProbabilitiesMultiArm <- function(
-        stageResults, 
+.getConditionalRejectionProbabilitiesMultiArm <- function(stageResults,
         ...,
-        stage = stageResults$stage, 
-        iterations = C_ITERATIONS_DEFAULT, 
+        stage = stageResults$stage,
+        iterations = C_ITERATIONS_DEFAULT,
         seed = NA_real_) {
     .assertIsValidStage(stage, stageResults$.design$kMax)
     gMax <- stageResults$getGMax()
 
     if (.isTrialDesignInverseNormal(stageResults$.design)) {
         return(.getConditionalRejectionProbabilitiesMultiArmInverseNormal(
-            stageResults = stageResults, 
-            stage = stage, 
+            stageResults = stageResults,
+            stage = stage,
             ...
         ))
     } else if (.isTrialDesignFisher(stageResults$.design)) {
         return(.getConditionalRejectionProbabilitiesMultiArmFisher(
-            stageResults = stageResults, 
-            stage = stage, 
+            stageResults = stageResults,
+            stage = stage,
             ...
         ))
     } else if (.isTrialDesignConditionalDunnett(stageResults$.design)) {
         return(.getConditionalRejectionProbabilitiesMultiArmConditionalDunnett(
-            stageResults = stageResults, 
+            stageResults = stageResults,
             ...
         ))
     }
@@ -1257,32 +1249,33 @@ getClosedConditionalDunnettTestResults <- function(
 
     .assertIsValidNPlanned(nPlanned = nPlanned, kMax = kMax, stage = stage)
     .assertIsSingleNumber(allocationRatioPlanned, "allocationRatioPlanned")
-    .assertIsInOpenInterval(allocationRatioPlanned, "allocationRatioPlanned", 0, C_ALLOCATION_RATIO_MAXIMUM)
+    .assertIsInOpenInterval(allocationRatioPlanned, "allocationRatioPlanned", 
+        lower = 0, upper = C_ALLOCATION_RATIO_MAXIMUM)
 
     if (stageResults$isDatasetMeans()) {
         .warnInCaseOfUnusedArgument(piTreatmentRange, "piTreatmentRange", NA_real_, "plot")
         .warnInCaseOfUnusedArgument(piControl, "piControl", NA_real_, "plot")
         return(.getConditionalPowerLikelihoodMeansMultiArm(
-            stageResults = stageResults, 
+            stageResults = stageResults,
             stage = stage,
-            nPlanned = nPlanned, 
+            nPlanned = nPlanned,
             allocationRatioPlanned = allocationRatioPlanned,
-            thetaRange = thetaRange, 
-            assumedStDevs = assumedStDevs, 
-            iterations = iterations, 
+            thetaRange = thetaRange,
+            assumedStDevs = assumedStDevs,
+            iterations = iterations,
             seed = seed
         ))
     } else if (stageResults$isDatasetRates()) {
         .warnInCaseOfUnusedArgument(thetaRange, "thetaRange", NA_real_, "plot")
         .warnInCaseOfUnusedArgument(assumedStDevs, "assumedStDevs", NA_real_, "plot")
         return(.getConditionalPowerLikelihoodRatesMultiArm(
-            stageResults = stageResults, 
+            stageResults = stageResults,
             stage = stage,
-            nPlanned = nPlanned, 
+            nPlanned = nPlanned,
             allocationRatioPlanned = allocationRatioPlanned,
-            piTreatmentRange = piTreatmentRange, 
+            piTreatmentRange = piTreatmentRange,
             piControl = piControl,
-            iterations = iterations, 
+            iterations = iterations,
             seed = seed
         ))
     } else if (stageResults$isDatasetSurvival()) {
@@ -1290,18 +1283,15 @@ getClosedConditionalDunnettTestResults <- function(
         .warnInCaseOfUnusedArgument(piControl, "piControl", NA_real_, "plot")
         .warnInCaseOfUnusedArgument(assumedStDevs, "assumedStDevs", NA_real_, "plot")
         return(.getConditionalPowerLikelihoodSurvivalMultiArm(
-            stageResults = stageResults, 
+            stageResults = stageResults,
             stage = stage,
-            nPlanned = nPlanned, 
+            nPlanned = nPlanned,
             allocationRatioPlanned = allocationRatioPlanned,
-            thetaRange = thetaRange, 
-            iterations = iterations, 
+            thetaRange = thetaRange,
+            iterations = iterations,
             seed = seed
         ))
     }
 
-    stop(
-        C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dataInput' type '",
-        .getClassName(stageResults$.dataInput), "' is not implemented yet"
-    )
+    .fireDataInputNotSupportedException(stageResults$getDataInput())
 }
