@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7132 $
-## |  Last changed: $Date: 2023-06-26 14:15:08 +0200 (Mon, 26 Jun 2023) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #' @include f_core_constants.R
 #' @include f_core_utilities.R
@@ -32,7 +28,7 @@ C_OUTPUT_FORMAT_ARGUMENTS <- c(
 C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
     "rpact.output.format.p.value" = "digits = 4, nsmall = 4",
     "rpact.output.format.repeated.p.value" = "digits = 4, nsmall = 4",
-    "rpact.output.format.probability" = "digits = 3, nsmall = 3",
+    "rpact.output.format.probability" = "digits = 4, nsmall = 4",
     "rpact.output.format.futility.probability" = "digits = 4, nsmall = 4, futilityProbabilityEnabled = TRUE",
     "rpact.output.format.sample.size" = "digits = 1, nsmall = 1",
     "rpact.output.format.event" = "digits = 1, nsmall = 1, trimSingleZeros = TRUE",
@@ -55,10 +51,7 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
 .getFormattedValue <- function(value, ..., digits, nsmall = NA_integer_,
         futilityProbabilityEnabled = FALSE, roundFunction = NA_character_, scientific = NA,
         trimEndingZerosAfterDecimalPoint = FALSE) {
-    if (missing(value)) {
-        return("NA")
-    }
-
+   
     if (is.null(value) || length(value) == 0) {
         return(value)
     }
@@ -70,7 +63,7 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
     if (futilityProbabilityEnabled) {
         value[value >= 0 & value < 1e-09] <- 0 # only futility probilities
     }
-
+    
     if (!is.na(roundFunction)) {
         if (roundFunction == "ceiling") {
             value <- ceiling(value * 10^digits) / 10^digits
@@ -82,7 +75,16 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
             value <- round(value, digits = digits)
         } else if (roundFunction == "signif ") {
             value <- signif(value, digits = digits)
+        } else {
+            stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
+                "invalid 'roundFunction' specified: ", dQuote(roundFunction))
         }
+        if (digits <= 0) {
+            return(value)
+        }
+    } else if (digits <= 0) {
+        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, 
+            "'digits' must be greater than 0 if no 'roundFunction' is specified")
     }
 
     if (is.na(nsmall)) {
@@ -137,8 +139,8 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
         return(4)
     }
 
-    fv <- .getFormattedValue(value[value >= 1e-4], digits = 4, nsmall = 4)
-    fv <- fv[!((1:length(fv)) %in% grep("e", fv))]
+    fv <- .getFormattedValue(value[value >= 1e-04], digits = 4, nsmall = 4)
+    fv <- fv[!((seq_len(length(fv))) %in% grep("e", fv))]
     numberOfCharacters <- ifelse(length(fv) > 0, nchar(fv[1]), 6)
     numberOfCharacters <- ifelse(numberOfCharacters < 6, 6, numberOfCharacters)
     decimalPlaces <- numberOfCharacters - 2
@@ -243,8 +245,15 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
     return(result)
 }
 
-.getOptionBasedFormattedValue <- function(optionKey, value, digits, nsmall = NA_integer_,
-        trimSingleZeros = FALSE, futilityProbabilityEnabled = FALSE, roundFunction = NA_character_) {
+.getOptionBasedFormattedValue <- function(
+        optionKey, 
+        value, 
+        digits, 
+        nsmall = NA_integer_,
+        trimSingleZeros = FALSE, 
+        futilityProbabilityEnabled = FALSE, 
+        roundFunction = NA_character_,
+        trimEndingZerosAfterDecimalPoint = FALSE) {
     outputFormatOptions <- .getOutputFormatOptions(optionKey)
     if (is.null(outputFormatOptions) || length(outputFormatOptions) == 0) {
         return(NULL)
@@ -271,8 +280,11 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
     }
 
     return(.getFormattedValue(value,
-        digits = digits, nsmall = nsmall,
-        futilityProbabilityEnabled = futilityProbabilityEnabled, roundFunction = roundFunction
+        digits = digits, 
+        nsmall = nsmall,
+        futilityProbabilityEnabled = futilityProbabilityEnabled, 
+        roundFunction = roundFunction,
+        trimEndingZerosAfterDecimalPoint = trimEndingZerosAfterDecimalPoint
     ))
 }
 
@@ -290,16 +302,22 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
 #
 # @param value a vector of p-values.
 #
-.formatPValues <- function(value) {
+.formatPValues <- function(value, repeated = FALSE) {
     if (sum(is.na(value)) == length(value)) {
         return(value)
     }
-
-    x <- .getOptionBasedFormattedValue("rpact.output.format.p.value",
-        value = value, digits = 4, nsmall = 4
-    )
-    if (!is.null(x)) {
-        return(x)
+    
+    optionKey = ifelse(repeated, 
+        "rpact.output.format.repeated.p.value", 
+        "rpact.output.format.p.value")
+    outputFormatOptions <- .getOutputFormatOptions(optionKey)
+    if (!is.null(outputFormatOptions) && length(outputFormatOptions) > 0) {
+        if (!is.null(outputFormatOptions[["digits"]])) {
+            digits <- outputFormatOptions[["digits"]]
+        }
+        if (!is.null(outputFormatOptions[["nsmall"]])) {
+            nsmall <- outputFormatOptions[["nsmall"]]
+        }
     }
 
     decimalPlaces <- .getPValueDecimalPlaces(value)
@@ -316,10 +334,13 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
     }
     text <- paste0(text, "1")
 
-    indices <- (value < threshold)
+    indices <- which(value < threshold)
     value[indices] <- threshold
     formattedValue <- .getFormattedValue(value, digits = 4, nsmall = 4)
     formattedValue[indices] <- text
+    if (repeated) {
+        formattedValue[value > 0.4999] <- ">0.5"
+    }
     return(formattedValue)
 }
 
@@ -336,15 +357,7 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
 # @param value a vector of p-values.
 #
 .formatRepeatedPValues <- function(value) {
-    x <- .getOptionBasedFormattedValue("rpact.output.format.repeated.p.value",
-        value = value, digits = 4, nsmall = 4
-    )
-    if (!is.null(x)) {
-        return(x)
-    }
-    pValues <- .formatPValues(value)
-    pValues[value > 0.4999] <- ">0.5"
-    return(pValues)
+    return(.formatPValues(value, repeated = TRUE))
 }
 
 #
@@ -358,35 +371,47 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
 # Digits = 4, nsmall = 4
 #
 .formatProbabilities <- function(value) {
-    x <- .getOptionBasedFormattedValue("rpact.output.format.probability",
-        value = value, digits = 4, nsmall = 4
-    )
-    if (!is.null(x)) {
-        return(x)
+    digits <- 4
+    nsmall <- 4
+    outputFormatOptions <- .getOutputFormatOptions("rpact.output.format.probability")
+    if (!is.null(outputFormatOptions) && length(outputFormatOptions) > 0) {
+        if (!is.null(outputFormatOptions[["digits"]])) {
+            digits <- outputFormatOptions[["digits"]]
+        }
+        if (!is.null(outputFormatOptions[["nsmall"]])) {
+            nsmall <- outputFormatOptions[["nsmall"]]
+        }
     }
+    
     value[abs(value) < 1e-08] <- 0
-    return(.getFormattedValue(value, digits = 4, nsmall = 4))
+    return(.getFormattedValue(value, digits = digits, nsmall = nsmall))
 }
 
-#
-# @title
-# Format Sample Sizes
-#
-# @description
-# Formats the output of sample sizes.
-#
-# @details
-# Digits = 1, nsmall = 1
-#
+#'
+#' @title
+#' Format Sample Sizes
+#'
+#' @description
+#' Formats the output of sample sizes.
+#'
+#' @details
+#' Digits = 1, nsmall = 1
+#'
+#' @noRd 
+#' 
 .formatSampleSizes <- function(value) {
-    x <- .getOptionBasedFormattedValue("rpact.output.format.sample.size",
-        value = value, digits = 1, nsmall = 1, trimSingleZeros = TRUE
+    x <- .getOptionBasedFormattedValue(
+        optionKey = "rpact.output.format.sample.size",
+        value = value, digits = 1, nsmall = 1, trimSingleZeros = TRUE,
+        trimEndingZerosAfterDecimalPoint = TRUE
     )
     if (!is.null(x)) {
         return(x)
     }
 
-    return(.getFormattedValue(.getZeroCorrectedValue(value), digits = 1, nsmall = 1, trimEndingZerosAfterDecimalPoint = TRUE))
+    return(.getFormattedValue(.getZeroCorrectedValue(value), 
+        digits = 1, nsmall = 1, 
+        trimEndingZerosAfterDecimalPoint = TRUE))
 }
 
 #
@@ -406,7 +431,8 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
     if (!is.null(x)) {
         return(x)
     }
-    return(.getFormattedValue(.getZeroCorrectedValue(value), digits = 1, nsmall = 1, trimEndingZerosAfterDecimalPoint = TRUE))
+    return(.getFormattedValue(.getZeroCorrectedValue(value), 
+        digits = 1, nsmall = 1, trimEndingZerosAfterDecimalPoint = TRUE))
 }
 
 #
@@ -420,15 +446,16 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
 # Digits = 4
 #
 .formatConditionalPower <- function(value) {
-    x <- .getOptionBasedFormattedValue("rpact.output.format.conditional.power",
-        value = value, digits = 4
-    )
-    if (!is.null(x)) {
-        return(x)
+    digits <- 4
+    outputFormatOptions <- .getOutputFormatOptions("rpact.output.format.conditional.power")
+    if (!is.null(outputFormatOptions) && length(outputFormatOptions) > 0) {
+        if (!is.null(outputFormatOptions[["digits"]])) {
+            digits <- outputFormatOptions[["digits"]]
+        }
     }
 
-    value <- round(value, digits = 4)
-    conditionalPower <- .getFormattedValue(value, digits = 4)
+    value <- round(value, digits = digits)
+    conditionalPower <- .getFormattedValue(value, digits = digits)
     conditionalPower[value == 0] <- "0"
     return(conditionalPower)
 }
@@ -723,6 +750,10 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
     return(.getFormattedValue(.getZeroCorrectedValue(value), digits = 3))
 }
 
+.formatSided <- function(value) {
+    return(ifelse(value == 1, "one-sided", "two-sided"))
+}
+
 .formatHowItIs <- function(value) {
     return(format(value, scientific = FALSE))
 }
@@ -787,6 +818,8 @@ C_OUTPUT_FORMAT_DEFAULT_VALUES <- pairlist(
 #' @param roundFunction A character value that specifies the R base round function
 #'        to use, default is \code{NA_character_}.
 #'        Allowed values are "ceiling", "floor", "trunc", "round", "signif", and \code{NA_character_}.
+#' @param persist A logical value indicating whether the output format settings 
+#'        should be saved persistently. Default is \code{TRUE}.
 #' @inheritParams param_three_dots
 #'
 #' @details
@@ -820,7 +853,8 @@ setOutputFormat <- function(parameterName = NA_character_, ...,
         futilityProbabilityEnabled = NA,
         file = NA_character_,
         resetToDefault = FALSE,
-        roundFunction = NA_character_) {
+        roundFunction = NA_character_,
+        persist = TRUE) {
     .assertIsCharacter(parameterName, "parameterName", naAllowed = TRUE)
     .assertIsSingleInteger(digits, "digits", naAllowed = TRUE, validateType = FALSE)
     .assertIsInClosedInterval(digits, "digits", lower = 0, upper = 20, naAllowed = TRUE)
@@ -831,7 +865,8 @@ setOutputFormat <- function(parameterName = NA_character_, ...,
     .assertIsSingleCharacter(file, "file", naAllowed = TRUE)
     .assertIsSingleLogical(resetToDefault, "resetToDefault")
     .assertIsSingleCharacter(roundFunction, "roundFunction", naAllowed = TRUE)
-
+    .assertIsSingleLogical(persist, "persist")
+    
     .warnInCaseOfUnknownArguments(functionName = "setOutputFormat", ...)
 
     if (resetToDefault) {
@@ -872,10 +907,8 @@ setOutputFormat <- function(parameterName = NA_character_, ...,
         }
         if (length(args) > 0) {
             base::options(args)
-            cat(length(args), " (of ", counter, " defined) output format", ifelse(length(args) == 1, "", "s"),
-                " successfully set via file\n",
-                sep = ""
-            )
+            message(length(args), " (of ", counter, " defined) output format", ifelse(length(args) == 1, "", "s"),
+                " successfully set via file")
         }
     }
 
@@ -912,22 +945,24 @@ setOutputFormat <- function(parameterName = NA_character_, ...,
             args <- list()
             args[[key]] <- cmd
             base::options(args)
-            cat("Output format successfully ", resetPrefix, 'set: "', key, '" = "', cmd, '"\n', sep = "")
+            message("Output format successfully ", resetPrefix, 'set: "', key, '" = "', cmd, '"')
             fields <- .getOutputFormatParameterNames(key)
             if (!is.null(fields) && length(fields) > 0) {
                 if (length(fields) == 1) {
-                    cat("This output format affects the following parameter:", fields, "\n")
+                    message("This output format affects the following parameter:", fields)
                 } else {
-                    cat("This output format affects ", length(fields),
-                        " parameters: ", .arrayToString(fields), "\n",
-                        sep = ""
-                    )
+                    message("This output format affects ", length(fields),
+                        " parameters: ", .arrayToString(fields))
                 }
             } else {
                 warning("The output format ", key, " affects no parameters", call. = FALSE)
             }
         }
     }
+    
+    if (persist) {
+        saveOptions()
+    }
 }
 
 .getOutputFormatKey <- function(parameterName, silent = FALSE) {
@@ -1205,11 +1240,11 @@ getOutputFormat <- function(parameterName = NA_character_, ...,
     if (is.null(fieldName) || length(fieldName) != 1 || is.na(fieldName)) {
         return(NULL)
     }
-    
+
     if (!(fieldName %in% names(C_PARAMETER_FORMAT_FUNCTIONS))) {
         return(NULL)
     }
-    
+
     functionName <- C_PARAMETER_FORMAT_FUNCTIONS[[fieldName]]
     if (is.null(functionName)) {
         return(NULL)
@@ -1229,5 +1264,5 @@ getOutputFormat <- function(parameterName = NA_character_, ...,
 
 .resetAllOutputFormats <- function() {
     base::options(C_OUTPUT_FORMAT_DEFAULT_VALUES)
-    cat(length(C_OUTPUT_FORMAT_DEFAULT_VALUES), "output formats were successfully reset\n")
+    message(length(C_OUTPUT_FORMAT_DEFAULT_VALUES), " output formats were successfully reset")
 }
