@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8575 $
-## |  Last changed: $Date: 2025-02-28 14:45:47 +0100 (Fr, 28 Feb 2025) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #' @include f_core_utilities.R
 NULL
@@ -54,8 +50,8 @@ NULL
                 )
             }
         } else {
-            numberOfNAs <- sum(as.vector(criticalValues) > 50, na.rm = TRUE)
-            if (any(is.na(criticalValues))) {
+            numberOfNAs <- sum(is.na(criticalValues))
+            if (numberOfNAs > 0) {
                 warning("The computation of ", .integerToWrittenNumber(numberOfNAs), " ",
                     "efficacy boundar", ifelse(numberOfNAs == 1, "y", "ies"), " ",
                     "on treatment effect scale not performed presumably ",
@@ -595,7 +591,8 @@ NULL
         if (identical(alternative, C_ALTERNATIVE_POWER_SIMULATION_DEFAULT)) {
             alternative <- C_ALTERNATIVE_POWER_SIMULATION_MEAN_RATIO_DEFAULT
         }
-        .assertIsInOpenInterval(alternative, "alternative", 0, NULL, naAllowed = TRUE)
+        .assertIsInOpenInterval(alternative, "alternative", 
+            lower = 0, upper = NULL, naAllowed = TRUE)
     }
 
     directionUpper <- .assertIsValidDirectionUpper(directionUpper,
@@ -720,6 +717,7 @@ NULL
     return(designPlan)
 }
 
+#' 
 #' @title
 #' Get Sample Size Means
 #'
@@ -757,7 +755,9 @@ NULL
 #'
 #' @export
 #'
-getSampleSizeMeans <- function(design = NULL, ...,
+getSampleSizeMeans <- function(
+        design = NULL, 
+        ...,
         groups = 2L,
         normalApproximation = FALSE,
         meanRatio = FALSE,
@@ -798,6 +798,7 @@ getSampleSizeMeans <- function(design = NULL, ...,
     return(.calculateSampleSizeMeansAndRates(designPlan))
 }
 
+#' 
 #' @title
 #' Get Power Means
 #'
@@ -853,7 +854,7 @@ getPowerMeans <- function(design = NULL, ...,
         allocationRatioPlanned = NA_real_ # C_ALLOCATION_RATIO_DEFAULT
         ) {
     .assertIsValidMaxNumberOfSubjects(maxNumberOfSubjects)
-
+    
     if ((length(stDev) == 1) && (groups == 2)) {
         stDev <- rep(stDev, 2)
     }
