@@ -13,49 +13,53 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8212 $
-## |  Last changed: $Date: 2024-09-13 14:01:23 +0200 (Fr, 13 Sep 2024) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 
-.addPlotSubTitleItems <- function(designPlan, designMaster, items, type) {
+.addPlotSubTitleItems <- function(designPlan, designMaster, main, type, ..., warningEnabled = FALSE) {
+    reducedParam <- NULL
+    if (warningEnabled && type %in% c(1:4)) {
+        reducedParam <- .warnInCaseOfUnusedValuesForPlotting(designPlan)
+    }
+    
     if (type %in% c(1, 3, 4)) {
-        return(invisible())
+        if (!is.null(reducedParam)) {
+            main$add(reducedParam$title, reducedParam$value, reducedParam$subscript)
+        }
+        return(invisible(main))
     }
 
     if (.isTrialDesignPlanMeans(designPlan)) {
         nMax <- designPlan$maxNumberOfSubjects[1] # use first value for plotting
 
         if (!(type %in% c(5))) {
-            items$add("N", round(nMax, 1), "max")
+            main$add("N", round(nMax, 1), "max")
         }
 
-        if ((type %in% c(5)) && !(items$title == "Sample Size")) {
-            items$add("N", round(nMax, 1), "max")
+        if ((type %in% c(5)) && !(main$title == "Sample Size")) {
+            main$add("N", round(nMax, 1), "max")
         }
 
         if (designPlan$meanRatio) {
-            items$add("coefficient of variation", designPlan$stDev)
+            main$add("coefficient of variation", designPlan$stDev)
         } else {
-            items$add("standard deviation", designPlan$stDev)
+            main$add("standard deviation", designPlan$stDev)
         }
 
         if (designPlan$groups == 1) {
             if (type %in% c(2, (5:9))) {
-                items$add("H0: mu", designPlan$thetaH0)
-                items$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
+                main$add("H0: mu", designPlan$thetaH0)
+                main$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
                     condition = (designPlan$allocationRatioPlanned != 1)
                 )
             }
         } else {
             if (type %in% c(2, (5:9))) {
                 if (designPlan$meanRatio) {
-                    items$add("H0: mean ratio", designPlan$thetaH0)
+                    main$add("H0: mean ratio", designPlan$thetaH0)
                 } else {
-                    items$add("H0: mean difference", designPlan$thetaH0)
+                    main$add("H0: mean difference", designPlan$thetaH0)
                 }
-                items$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
+                main$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
                     condition = (designPlan$allocationRatioPlanned != 1)
                 )
             }
@@ -64,58 +68,63 @@
         nMax <- designPlan$maxNumberOfSubjects[1] # use first value for plotting
 
         if (!(type %in% c(5))) {
-            items$add("N", round(nMax, 1), "max")
+            main$add("N", round(nMax, 1), "max")
         }
 
-        if ((type %in% c(5)) && !(items$title == "Sample Size")) {
-            items$add("N", round(nMax, 1), "max")
+        if ((type %in% c(5)) && !(main$title == "Sample Size")) {
+            main$add("N", round(nMax, 1), "max")
         }
 
         if (designPlan$groups == 2 && !(type %in% c(3, 4)) &&
                 length(designPlan$pi2) == 1 && !is.na(designPlan$pi2)) {
-            items$add("pi", designPlan$pi2, 2)
+            main$add("pi", designPlan$pi2, 2)
         }
 
         if (designPlan$groups == 1) {
             if (type %in% c(2, (5:9))) {
-                items$add("H0: pi", designPlan$thetaH0)
+                main$add("H0: pi", designPlan$thetaH0)
             }
         } else {
             if (type %in% c(2, (5:9))) {
                 if (designPlan$riskRatio) {
-                    items$add("H0: risk ratio", designPlan$thetaH0)
+                    main$add("H0: risk ratio", designPlan$thetaH0)
                 } else {
-                    items$add("H0: risk difference", designPlan$thetaH0)
+                    main$add("H0: risk difference", designPlan$thetaH0)
                 }
-                items$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
+                main$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
                     condition = (designPlan$allocationRatioPlanned != 1)
                 )
             }
         }
     } else if (.isTrialDesignPlanSurvival(designPlan)) {
         if (designPlan$.isPowerObject() && !(type %in% (13:14))) {
-            items$add("maximum number of events", designPlan$maxNumberOfEvents[1])
+            main$add("maximum number of events", designPlan$maxNumberOfEvents[1])
         }
         if (type %in% (10:12)) {
-            items$add("maximum number of subjects", designPlan$maxNumberOfSubjects[1])
+            main$add("maximum number of subjects", designPlan$maxNumberOfSubjects[1])
         }
         if (type %in% c(2, (5:12))) {
-            items$add("H0: hazard ratio", designPlan$thetaH0)
-            items$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
+            main$add("H0: hazard ratio", designPlan$thetaH0)
+            main$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
                 condition = (designPlan$allocationRatioPlanned != 1)
             )
         }
     } else if (.isTrialDesignPlanCountData(designPlan)) {
         if (type %in% c(2, (5:9))) {
-            items$add("H0: lambda(1) / lambda(2)", designPlan$thetaH0)
+            main$add("H0: lambda(1) / lambda(2)", designPlan$thetaH0)
             if (length(designPlan$theta) == 1) {
-                items$add("H1: effect", designPlan$theta)
+                main$add("H1: effect", designPlan$theta)
             }
-            items$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
+            main$add("allocation ratio", round(designPlan$allocationRatioPlanned, 2),
                 condition = (designPlan$allocationRatioPlanned != 1)
             )
         }
     }
+    
+    if (!is.null(reducedParam)) {
+        main$add(reducedParam$title, reducedParam$value, reducedParam$subscript)
+    }
+    return(invisible(main))
 }
 
 .assertIsValidVariedParameterVectorForPlotting <- function(designPlan, plotType) {
@@ -175,6 +184,44 @@
     return(list(theta = designPlan[[thetaName]], thetaName = thetaName))
 }
 
+.getPlotAlphaBetaSpentParameterNames <- function(designMaster, ...) {
+    if (.isTrialDesignFisher(designMaster) ||
+            designMaster$typeBetaSpending == C_TYPE_OF_DESIGN_BS_NONE) {
+        return("alphaSpent")
+    }
+    
+    alphaSpentEnabled <- .getOptionalArgument("showAlphaSpent", ..., optionalArgumentDefaultValue = NA)
+    if (is.na(alphaSpentEnabled)) {
+        alphaSpentEnabled <- isTRUE(as.logical(getOption("rpact.plot.show.alpha.spent", TRUE)))
+    }
+
+    betaSpentEnabled <- .getOptionalArgument("showBetaSpent", ..., optionalArgumentDefaultValue = NA)
+    if (is.na(betaSpentEnabled)) {
+        betaSpentEnabled <- isTRUE(as.logical(getOption("rpact.plot.show.beta.spent", FALSE)))
+    }
+    
+    yParameterNames <- character()
+    if (alphaSpentEnabled) {
+        yParameterNames <- c(yParameterNames, "alphaSpent")
+    }
+    if (betaSpentEnabled) {
+        yParameterNames <- c(yParameterNames, "betaSpent")
+    }
+    if (length(yParameterNames) == 0) {
+        yParameterNames <- "alphaSpent"
+        if (isFALSE(as.logical(getOption("rpact.plot.show.alpha.spent", TRUE))) &&
+                isFALSE(as.logical(getOption("rpact.plot.show.beta.spent", TRUE)))) {
+            warning("Options 'rpact.plot.show.alpha.spent' and ",
+                "'rpact.plot.show.beta.spent' are both FALSE; ",
+                "'alphaSpent' will be shown", call. = FALSE)
+        } else {
+            warning("'showAlphaSpent' and 'showBetaSpent' are both FALSE; ",
+                "'alphaSpent' will be shown", call. = FALSE)
+        }
+    }
+    return(yParameterNames)
+}
+
 .plotTrialDesignPlan <- function(designPlan,
         type = 1L,
         main = NA_character_,
@@ -186,7 +233,9 @@
         legendPosition = NA_integer_,
         showSource = FALSE,
         designPlanName = NA_character_,
-        plotSettings = NULL, ...) {
+        plotSettings = NULL, 
+        ...) {
+        
     .assertGgplotIsInstalled()
     .assertIsTrialDesignPlan(designPlan)
     .assertIsValidLegendPosition(legendPosition)
@@ -242,20 +291,11 @@
     }
 
     srcCmd <- NULL
-
-    reducedParam <- NULL
-    if (type %in% c(1:4)) {
-        reducedParam <- .warnInCaseOfUnusedValuesForPlotting(designPlan)
-    }
-
-    if (type == 1) { # Boundary plot
+    if (type == 1) { # Boundaries Z Scale
         if (survivalDesignPlanEnabled) {
             if (is.na(main)) {
                 main <- PlotSubTitleItems$new(title = "Boundaries Z Scale")
-                .addPlotSubTitleItems(designPlan, designMaster, main, type)
-                if (!is.null(reducedParam)) {
-                    main$add(reducedParam$title, reducedParam$value, reducedParam$subscript)
-                }
+                .addPlotSubTitleItems(designPlan, designMaster, main, type, warningEnabled = TRUE)
             }
 
             if (designMaster$sided == 1) {
@@ -299,31 +339,33 @@
         } else {
             if (is.na(main)) {
                 main <- PlotSubTitleItems$new(title = "Boundaries")
-                .addPlotSubTitleItems(designPlan, designMaster, main, type)
-                if (!is.null(reducedParam)) {
-                    main$add(reducedParam$title, reducedParam$value, reducedParam$subscript)
-                }
+                .addPlotSubTitleItems(designPlan, designMaster, main, type, warningEnabled = TRUE)
             }
 
             designSet <- TrialDesignSet$new(design = designMaster, singleDesign = TRUE)
             designSet$.plotSettings <- designPlan$.plotSettings
             designPlanName <- paste0(designPlanName, "$.design")
             return(.plotTrialDesignSet(
-                x = designSet, y = NULL, main = main,
-                xlab = xlab, ylab = ylab, type = type,
-                palette = palette, theta = .plotTheta(theta), nMax = nMax,
-                plotPointsEnabled = plotPointsEnabled, legendPosition = legendPosition,
-                designSetName = designPlanName, showSource = showSource,
-                plotSettings = plotSettings # , ...
+                x = designSet, 
+                y = NULL, 
+                main = main,
+                xlab = xlab, 
+                ylab = ylab, 
+                type = type,
+                palette = palette, 
+                theta = .plotTheta(theta), 
+                nMax = nMax,
+                plotPointsEnabled = plotPointsEnabled, 
+                legendPosition = legendPosition,
+                designSetName = designPlanName, 
+                showSource = showSource,
+                plotSettings = plotSettings 
             ))
         }
-    } else if (type == 2) { # Effect Scale Boundary plot
+    } else if (type == 2) { # Boundaries Effect Scale
         if (is.na(main)) {
             main <- PlotSubTitleItems$new(title = "Boundaries Effect Scale")
-            .addPlotSubTitleItems(designPlan, designMaster, main, type)
-            if (!is.null(reducedParam)) {
-                main$add(reducedParam$title, reducedParam$value, reducedParam$subscript)
-            }
+            .addPlotSubTitleItems(designPlan, designMaster, main, type, warningEnabled = TRUE)
         }
 
         if (is.na(ylab)) {
@@ -426,10 +468,6 @@
             legendPosition <- C_POSITION_RIGHT_TOP
         }
 
-        if (is.na(legendPosition)) {
-            legendPosition <- C_POSITION_RIGHT_TOP
-        }
-
         srcCmd <- .showPlotSourceInformation(
             objectName = designPlanName,
             xParameterName = xParameterNameSrc,
@@ -457,50 +495,68 @@
         } else {
             designPlan <- data
         }
-    } else if (type == 3) { # Stage Levels
+    } else if (type == 3) { # Boundaries p Values Scale
         if (is.na(main)) {
             main <- PlotSubTitleItems$new(title = "Boundaries p Values Scale")
-            .addPlotSubTitleItems(designPlan, designMaster, main, type)
-            if (!is.null(reducedParam)) {
-                main$add(reducedParam$title, reducedParam$value, reducedParam$subscript)
-            }
+            .addPlotSubTitleItems(designPlan, designMaster, main, type, warningEnabled = TRUE)
         }
 
+        df <- NULL
         if (survivalDesignPlanEnabled) {
             xParameterName <- "cumulativeEventsPerStage"
-            yParameterNames <- "stageLevels"
-            designPlan <- data.frame(
-                cumulativeEventsPerStage = designPlan$cumulativeEventsPerStage[, 1],
-                stageLevels = designMaster$stageLevels
-            )
             xParameterNameSrc <- "cumulativeEventsPerStage[, 1]"
-            yParameterNamesSrc <- ".design$stageLevels"
+            df <- data.frame(
+                cumulativeEventsPerStage = designPlan$cumulativeEventsPerStage[, 1],
+                criticalValuesPValueScale = designPlan$criticalValuesPValueScale
+            )
         } else {
-            xParameterName <- "informationRates"
-            yParameterNames <- "stageLevels"
-            designPlan <- TrialDesignSet$new(design = designMaster, singleDesign = TRUE)
-            xParameterNameSrc <- ".design$informationRates"
-            yParameterNamesSrc <- ".design$stageLevels"
+            xParameterName <- "numberOfSubjects"
+            xParameterNameSrc <- xParameterName
+            df <- data.frame(
+                numberOfSubjects = designPlan$numberOfSubjects[, 1],
+                criticalValuesPValueScale = designPlan$criticalValuesPValueScale,
+                futilityBoundsPValueScale = c(designPlan$futilityBoundsPValueScale, 
+                    designPlan$criticalValuesPValueScale[length(designPlan$criticalValuesPValueScale)])
+            )
         }
-
+        
+        yParameterNames <- "criticalValuesPValueScale"
+        futilityBoundsPValueScaleEnabled <- isTRUE(as.logical(
+            getOption("rpact.plot.show.futility.on.pvalue.scale", FALSE))) || 
+            isTRUE(.getOptionalArgument("showFutilityBounds", ..., optionalArgumentDefaultValue = FALSE))
+        if (futilityBoundsPValueScaleEnabled && 
+                !all(is.na(designMaster$futilityBounds)) && 
+                any(designMaster$futilityBounds > C_FUTILITY_BOUNDS_DEFAULT, na.rm = TRUE)) {
+            yParameterNames <- c(yParameterNames, "futilityBoundsPValueScale")
+            df$futilityBoundsPValueScale = c(designPlan$futilityBoundsPValueScale, 
+                designPlan$criticalValuesPValueScale[length(designPlan$criticalValuesPValueScale)])
+        }
+        yParameterNamesSrc <- yParameterNames
+        
+        if (!is.null(df)) {
+            designPlan <- df
+        }
+        
+        if (is.na(legendPosition)) {
+            legendPosition <- C_POSITION_OUTSIDE_BOTTOM
+        }
+        
         srcCmd <- .showPlotSourceInformation(
             objectName = designPlanName,
             xParameterName = xParameterNameSrc,
             yParameterNames = yParameterNamesSrc,
-            hint = showSourceHint, nMax = nMax,
-            type = type, showSource = showSource
+            hint = showSourceHint, 
+            nMax = nMax,
+            type = type, 
+            showSource = showSource
         )
     } else if (type == 4) { # Alpha Spending
         if (is.na(main)) {
             main <- PlotSubTitleItems$new(title = "Error Spending")
-            .addPlotSubTitleItems(designPlan, designMaster, main, type)
-            if (!is.null(reducedParam)) {
-                main$add(reducedParam$title, reducedParam$value, reducedParam$subscript)
-            }
+            .addPlotSubTitleItems(designPlan, designMaster, main, type, warningEnabled = TRUE)
         }
         if (survivalDesignPlanEnabled) {
             xParameterName <- "cumulativeEventsPerStage"
-            yParameterNames <- "alphaSpent"
             designPlan <- data.frame(
                 cumulativeEventsPerStage = designPlan$cumulativeEventsPerStage[, 1],
                 alphaSpent = designMaster$alphaSpent
@@ -509,11 +565,11 @@
             yParameterNamesSrc <- ".design$alphaSpent"
         } else {
             xParameterName <- "informationRates"
-            yParameterNames <- "alphaSpent"
             designPlan <- TrialDesignSet$new(design = designMaster, singleDesign = TRUE)
             xParameterNameSrc <- ".design$informationRates"
             yParameterNamesSrc <- ".design$alphaSpent"
         }
+        yParameterNames <- .getPlotAlphaBetaSpentParameterNames(designMaster, ...)
         plotPointsEnabled <- ifelse(is.na(plotPointsEnabled), FALSE, plotPointsEnabled)
 
         srcCmd <- .showPlotSourceInformation(
@@ -529,7 +585,11 @@
 
         if (designPlan$.isSampleSizeObject()) {
             if (is.na(main)) {
-                main <- PlotSubTitleItems$new(title = "Sample Size")
+                main <- PlotSubTitleItems$new(title = ifelse(
+                    survivalDesignPlanEnabled || inherits(designPlan, "SimulationResultsSurvival"),
+                    "Number of Events", 
+                    "Sample Size"
+                ))
                 .addPlotSubTitleItems(designPlan, designMaster, main, type)
             }
 
@@ -619,14 +679,22 @@
             }
 
             return(.plotParameterSet(
-                parameterSet = designPlan, designMaster = designMaster,
+                parameterSet = designPlan, 
+                designMaster = designMaster,
                 xParameterName = xParameterName,
-                yParameterNames = yParameterNames, mainTitle = main, xlab = xlab, ylab = ylab,
-                palette = palette, theta = .plotTheta(theta),
-                nMax = nMax, plotPointsEnabled = plotPointsEnabled,
-                legendPosition = legendPosition, variedParameters = variedParameters,
-                qnormAlphaLineEnabled = FALSE, yAxisScalingEnabled = FALSE,
-                plotSettings = plotSettings # , ...
+                yParameterNames = yParameterNames, 
+                mainTitle = main, 
+                xlab = xlab, 
+                ylab = ylab,
+                palette = palette, 
+                theta = .plotTheta(theta),
+                nMax = nMax, 
+                plotPointsEnabled = plotPointsEnabled,
+                legendPosition = legendPosition, 
+                variedParameters = variedParameters,
+                qnormAlphaLineEnabled = FALSE, 
+                yAxisScalingEnabled = FALSE,
+                plotSettings = plotSettings 
             ))
         } else {
             if (is.na(main)) {
@@ -811,8 +879,9 @@
                 }
             }
         } else if (.isTrialDesignPlanCountData(designPlan)) {
-            if (designPlan$.getParameterType("expectedNumberOfSubjectsH1") != C_PARAM_GENERATED) {
-                stop("Plot type 9 is only available for count data endpoint if 'expectedNumberOfSubjectsH1' was not calculated")
+            if (!designPlan$isGeneratedParameter("expectedNumberOfSubjectsH1")) {
+                stop("Plot type 9 is only available for count data endpoint ",
+                    "if 'expectedNumberOfSubjectsH1' was not calculated")
             }
 
             xParameterName <- "theta"
@@ -903,19 +972,31 @@
 
             return(.plotDataFrame(data,
                 mainTitle = main,
-                xlab = NA_character_, ylab = NA_character_, xAxisLabel = "Hazard Ratio",
-                yAxisLabel1 = "Analysis Time", yAxisLabel2 = NA_character_,
-                plotPointsEnabled = TRUE, legendTitle = "Stage",
-                legendPosition = legendPosition, sided = designMaster$sided,
+                xlab = NA_character_, 
+                ylab = NA_character_, 
+                xAxisLabel = "Hazard Ratio",
+                yAxisLabel1 = "Analysis Time", 
+                yAxisLabel2 = NA_character_,
+                plotPointsEnabled = TRUE, 
+                legendTitle = "Stage",
+                legendPosition = legendPosition, 
+                sided = designMaster$sided,
                 plotSettings = plotSettings, ...
             ))
         } else if (type == 13 || type == 14) { # Cumulative Distribution Function / Survival function
-            return(.plotSurvivalFunction(designPlan,
-                designMaster = designMaster, type = type, main = main,
-                xlab = xlab, ylab = ylab, palette = palette,
-                legendPosition = legendPosition, showSource = showSource,
+            return(.plotSurvivalFunction(
+                designPlan,
+                designMaster = designMaster, 
+                type = type, 
+                main = main,
+                xlab = xlab, 
+                ylab = ylab, 
+                palette = palette,
+                legendPosition = legendPosition, 
+                showSource = showSource,
                 designPlanName = designPlanName,
-                plotSettings = plotSettings, ...
+                plotSettings = plotSettings, 
+                ...
             ))
         } else {
             stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'type' (", type, ") is not allowed; must be 1, 2, ..., 14")
@@ -930,17 +1011,36 @@
         }
         return(srcCmd)
     }
-
-    p <- .plotParameterSet(
-        parameterSet = designPlan, designMaster = designMaster,
+    
+    args <- list(
+        parameterSet = designPlan, 
+        designMaster = designMaster,
         xParameterName = xParameterName,
-        yParameterNames = yParameterNames, mainTitle = main, xlab = xlab, ylab = ylab,
-        palette = palette, theta = .plotTheta(theta),
-        nMax = nMax, plotPointsEnabled = plotPointsEnabled,
-        legendPosition = legendPosition, variedParameters = variedParameters,
-        qnormAlphaLineEnabled = (type != 2), ratioEnabled = ratioEnabled,
-        plotSettings = plotSettings # , ...
+        yParameterNames = yParameterNames, 
+        mainTitle = main, 
+        xlab = xlab, 
+        ylab = ylab,
+        palette = palette, 
+        theta = .plotTheta(theta),
+        nMax = nMax, 
+        plotPointsEnabled = plotPointsEnabled,
+        legendPosition = legendPosition, 
+        variedParameters = variedParameters,
+        qnormAlphaLineEnabled = (type != 2), 
+        ratioEnabled = ratioEnabled,
+        plotSettings = plotSettings 
     )
+    
+    showBetaSpent <- .getOptionalArgument("showBetaSpent", ..., optionalArgumentDefaultValue = NA)
+    if (!is.na(showBetaSpent)) {
+        args$showBetaSpent <- showBetaSpent
+    }
+    showFutilityBound <- .getOptionalArgument("showFutilityBound", ..., optionalArgumentDefaultValue = NA)
+    if (!is.na(showFutilityBound)) {
+        args$showFutilityBound <- showFutilityBound
+    }
+    
+    p <- do.call(.plotParameterSet, args = args)
 
     if (type == 1 && survivalDesignPlanEnabled) {
         p <- .addDecisionCriticalValuesToPlot(p = p, designMaster = designMaster, type = type, nMax = nMax)
@@ -1259,11 +1359,18 @@
 
     return(.plotDataFrame(data2,
         mainTitle = main,
-        xlab = xlab, ylab = ylab, xAxisLabel = "Time",
-        yAxisLabel1 = yAxisLabel1, yAxisLabel2 = "Lambda",
-        plotPointsEnabled = FALSE, legendTitle = NA_character_,
-        legendPosition = legendPosition, scalingFactor1 = 1,
-        scalingFactor2 = scalingFactor, palette = palette, sided = designMaster$sided,
+        xlab = xlab, 
+        ylab = ylab, 
+        xAxisLabel = "Time",
+        yAxisLabel1 = yAxisLabel1, 
+        yAxisLabel2 = "Lambda",
+        plotPointsEnabled = FALSE, 
+        legendTitle = NA_character_,
+        legendPosition = legendPosition, 
+        scalingFactor1 = 1,
+        scalingFactor2 = scalingFactor, 
+        palette = palette, 
+        sided = designMaster$sided,
         plotSettings = plotSettings
     ))
 }
@@ -1314,6 +1421,28 @@
     return(NULL)
 }
 
+.getUsedValueForPlotting <- function(designPlan) {
+    if (.isTrialDesignPlanMeans(designPlan) && designPlan$.isSampleSizeObject()) {
+        value <- designPlan$alternative[1]
+        names(value) <- "alternative"
+        return(value)
+    }
+    
+    if (.isTrialDesignPlanRates(designPlan) && designPlan$.isSampleSizeObject()) {
+        value <- designPlan$pi1[1]
+        names(value) <- "pi1"
+        return(value)
+    }
+    
+    if (.isTrialDesignPlanSurvival(designPlan) && designPlan$.isSampleSizeObject()) {
+        value <- designPlan$hazardRatio[1]
+        names(value) <- "hazardRatio"
+        return(value)
+    }
+    
+    return(NULL)
+}
+
 #'
 #' @title
 #' Trial Design Plan Plotting
@@ -1395,6 +1524,8 @@ plot.TrialDesignPlan <- function(
         markdown <- .isMarkdownEnabled("plot")
     }
     
+    .showWarningIfPlotArgumentWillBeIgnored(type, ..., obj = x)
+    
     args <- list(
         x = x, 
         y = NULL,
@@ -1409,6 +1540,7 @@ plot.TrialDesignPlan <- function(
         showSource = showSource,
         grid = grid,
         plotSettings = plotSettings, 
+        markdown = markdown, 
         ...)
 
     if (markdown) {
@@ -1417,12 +1549,20 @@ plot.TrialDesignPlan <- function(
             grid <- 0
             args$grid <- 0
         }
+        if (!all(is.na(type)) && length(type) == 1 && grid == 0) {
+            grid <- 1
+            args$grid <- 1
+        }
+        
         if (grid > 0) {
             print(do.call(.plot.TrialDesignPlan, args))            
         } else {
-            do.call(.plot.TrialDesignPlan, args)
+            # if grid = 0 the charts will be printed later in .createPlotResultObject()
+            do.call(.plot.TrialDesignPlan, args) 
         }
-        return(.knitPrintQueue(x, sep = sep, prefix = sep))
+        return(.knitPrintQueue(x, sep = sep, prefix = sep, 
+            resetPipeOperatorQueue = (all(is.na(type)) || length(type) == 1)
+        ))
     }
     
     return(do.call(.plot.TrialDesignPlan, args))
@@ -1453,7 +1593,8 @@ plot.TrialDesignPlan <- function(
     if (!is.null(nMax)) {
         warning(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'nMax' (", nMax,
-            ") will be ignored because it will be taken from design plan"
+            ") will be ignored because it will be taken from design plan",
+            call. = FALSE
         )
     }
 
@@ -1480,11 +1621,18 @@ plot.TrialDesignPlan <- function(
     for (typeNumber in typeNumbers) {
         p <- .plotTrialDesignPlan(
             designPlan = x,
-            main = main, xlab = xlab, ylab = ylab, type = typeNumber,
-            palette = palette, theta = theta, plotPointsEnabled = plotPointsEnabled,
+            main = main, 
+            xlab = xlab, 
+            ylab = ylab, 
+            type = typeNumber,
+            palette = palette, 
+            theta = theta, 
+            plotPointsEnabled = plotPointsEnabled,
             legendPosition = .getGridLegendPosition(legendPosition, typeNumbers, grid),
-            showSource = showSource, designPlanName = designPlanName,
-            plotSettings = plotSettings, ...
+            showSource = showSource, 
+            designPlanName = designPlanName,
+            plotSettings = plotSettings, 
+            ...
         )
         .printPlotShowSourceSeparator(showSource, typeNumber, typeNumbers)
         if (length(typeNumbers) > 1) {
