@@ -13,10 +13,6 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8624 $
-## |  Last changed: $Date: 2025-03-21 13:24:59 +0100 (Fr, 21 Mrz 2025) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #' @include f_logger.R
 NULL
@@ -74,23 +70,30 @@ NULL
 }
 
 .getTestthatResultLine <- function(fileContent) {
-    if (grepl("\\[ OK:", fileContent)) {
-        indexStart <- regexpr("\\[ OK: \\d", fileContent)[[1]]
-        indexEnd <- regexpr("FAILED: \\d{1,5} \\]", fileContent)
-        indexEnd <- indexEnd[[1]] + attr(indexEnd, "match.length") - 1
-        resultPart <- substr(fileContent, indexStart, indexEnd)
-        return(resultPart)
-    }
+    tryCatch(
+        {
+            if (grepl("\\[ OK:", fileContent)) {
+                indexStart <- regexpr("\\[ OK: \\d", fileContent)[[1]]
+                indexEnd <- regexpr("FAILED: \\d{1,5} \\]", fileContent)
+                indexEnd <- indexEnd[[1]] + attr(indexEnd, "match.length") - 1
+                resultPart <- substr(fileContent, indexStart, indexEnd)
+                return(resultPart)
+            }
 
-    indexStart <- regexpr("\\[ FAIL \\d", fileContent)[[1]]
-    if (indexStart == -1) {
-        return("[ FAIL 0 | WARN 0 | SKIP 0 | PASS 0 ]")
-    }
+            indexStart <- regexpr("\\[ FAIL \\d", fileContent)[[1]]
+            if (indexStart == -1) {
+                return("[ FAIL 0 | WARN 0 | SKIP 0 | PASS 0 ]")
+            }
 
-    indexEnd <- regexpr("PASS \\d{1,5} \\]", fileContent)
-    indexEnd <- indexEnd[[1]] + attr(indexEnd, "match.length") - 1
-    resultPart <- substr(fileContent, indexStart, indexEnd)
-    return(resultPart)
+            indexEnd <- regexpr("PASS \\d{1,5} \\]", fileContent)
+            indexEnd <- indexEnd[[1]] + attr(indexEnd, "match.length") - 1
+            resultPart <- substr(fileContent, indexStart, indexEnd)
+            return(resultPart)
+        },
+        error = function(e) {
+            return(NA_character_)
+        }
+    )
 }
 
 .getTestthatResultNumberOfTests <- function(fileContent) {
@@ -109,35 +112,49 @@ NULL
 }
 
 .getTestthatResultNumberOfFailures <- function(fileContent) {
-    if (grepl("FAILED:", fileContent)) {
-        line <- .getTestthatResultLine(fileContent)
-        index <- regexpr("FAILED: \\d{1,5} \\]", line)
-        indexStart <- index[[1]] + 8
-        indexEnd <- index[[1]] + attr(index, "match.length") - 3
-        return(substr(line, indexStart, indexEnd))
-    }
+    tryCatch(
+        {
+            if (grepl("FAILED:", fileContent)) {
+                line <- .getTestthatResultLine(fileContent)
+                index <- regexpr("FAILED: \\d{1,5} \\]", line)
+                indexStart <- index[[1]] + 8
+                indexEnd <- index[[1]] + attr(index, "match.length") - 3
+                return(as.integer(substr(line, indexStart, indexEnd)))
+            }
 
-    line <- .getTestthatResultLine(fileContent)
-    index <- regexpr("FAIL \\d{1,5} ", line)
-    indexStart <- index[[1]] + 5
-    indexEnd <- index[[1]] + attr(index, "match.length") - 2
-    return(substr(line, indexStart, indexEnd))
+            line <- .getTestthatResultLine(fileContent)
+            index <- regexpr("FAIL \\d{1,5} ", line)
+            indexStart <- index[[1]] + 5
+            indexEnd <- index[[1]] + attr(index, "match.length") - 2
+            return(as.integer(substr(line, indexStart, indexEnd)))
+        },
+        error = function(e) {
+            return(NA_integer_)
+        }
+    )
 }
 
 .getTestthatResultNumberOfSkippedTests <- function(fileContent) {
-    if (grepl("SKIPPED:", fileContent)) {
-        line <- .getTestthatResultLine(fileContent)
-        index <- regexpr("SKIPPED: \\d{1,5} {1,1}", line)
-        indexStart <- index[[1]] + 9
-        indexEnd <- index[[1]] + attr(index, "match.length") - 2
-        return(substr(line, indexStart, indexEnd))
-    }
+    tryCatch(
+        {
+            if (grepl("SKIPPED:", fileContent)) {
+                line <- .getTestthatResultLine(fileContent)
+                index <- regexpr("SKIPPED: \\d{1,5} {1,1}", line)
+                indexStart <- index[[1]] + 9
+                indexEnd <- index[[1]] + attr(index, "match.length") - 2
+                return(as.integer(substr(line, indexStart, indexEnd)))
+            }
 
-    line <- .getTestthatResultLine(fileContent)
-    index <- regexpr("SKIP \\d{1,5} {1,1}", line)
-    indexStart <- index[[1]] + 5
-    indexEnd <- index[[1]] + attr(index, "match.length") - 2
-    return(substr(line, indexStart, indexEnd))
+            line <- .getTestthatResultLine(fileContent)
+            index <- regexpr("SKIP \\d{1,5} {1,1}", line)
+            indexStart <- index[[1]] + 5
+            indexEnd <- index[[1]] + attr(index, "match.length") - 2
+            return(as.integer(substr(line, indexStart, indexEnd)))
+        },
+        error = function(e) {
+            return(NA_integer_)
+        }
+    )
 }
 
 # testFileTargetDirectory <- "D:/R/_temp/test_debug"
@@ -577,6 +594,170 @@ NULL
     saveOptions()
 }
 
+
+#' Check if Startup Messaging is Enabled
+#'
+#' @description
+#' This function checks whether the startup messages for the `rpact` package are enabled.
+#' It also ensures that the messages are displayed only once within a 72-hour period.
+#'
+#' @details
+#' The function retrieves the `rpact.startup.message.enabled` option to determine if startup
+#' messages are enabled. If enabled, it checks the last timestamp when the message was shown
+#' and ensures that the message is displayed again only if more than 72 hours have passed.
+#' The timestamp is updated after the message is shown.
+#'
+#' @return
+#' Returns \code{TRUE} if startup messaging is enabled and should be displayed, otherwise \code{FALSE}.
+#'
+#' @examples
+#' \dontrun{
+#' if (.isStartupMessagingEnabled()) {
+#'     message("Welcome to rpact!")
+#' }
+#' }
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
+.isStartupMessagingEnabled <- function() {
+    if (isFALSE(as.logical(base::getOption("rpact.startup.message.enabled")))) {
+        return(FALSE)
+    }
+
+    lastShownTime <- base::getOption("rpact.startup.message.timestamp")
+    currentTime <- Sys.time()
+    if (is.null(lastShownTime) || !grepl("^\\d{4}-\\d{2}-\\d{2} \\d{2}:\\d{2}:\\d{2}", lastShownTime)) {
+        base::options("rpact.startup.message.timestamp" = currentTime)
+        return(TRUE)
+    }
+
+    lastShownTime <- as.POSIXct(lastShownTime, tz = "UTC")
+    timeDiff <- as.numeric(difftime(currentTime, lastShownTime, units = "mins"))
+
+    # If the time difference is greater than 72 hours, show the message again
+    if (timeDiff > 72 * 60) {
+        base::options("rpact.startup.message.timestamp" = currentTime)
+        saveOptions()
+        return(TRUE)
+    }
+
+    return(FALSE)
+}
+
+#' Disable Startup Messages
+#'
+#' @description
+#' This function disables the startup messages for the `rpact` package by setting
+#' the `rpact.startup.message.enabled` option to `FALSE`.
+#'
+#' @details
+#' Once this function is called, the startup messages will remain disabled until
+#' explicitly re-enabled using the `enableStartupMessages()` function. The current
+#' state is saved using the `saveOptions()` function.
+#'
+#' @return
+#' This function does not return a value. It is called for its side effects.
+#'
+#' @examples
+#' \dontrun{
+#' disableStartupMessages()
+#' }
+#'
+#' @export
+#'
+#' @keywords internal
+#'
+disableStartupMessages <- function() {
+    if (isFALSE(as.logical(base::getOption("rpact.startup.message.enabled")))) {
+        return(invisible())
+    }
+
+    base::options("rpact.startup.message.enabled" = FALSE)
+    saveOptions()
+}
+
+#' Enable Startup Messages
+#'
+#' @description
+#' This function enables the startup messages for the `rpact` package by setting
+#' the `rpact.startup.message.enabled` option to `TRUE`.
+#'
+#' @details
+#' Once this function is called, the startup messages will remain enabled until
+#' explicitly disabled using the `disableStartupMessages()` function. The current
+#' state is saved using the `saveOptions()` function.
+#'
+#' @return
+#' This function does not return a value. It is called for its side effects.
+#'
+#' @examples
+#' \dontrun{
+#' enableStartupMessages()
+#' }
+#'
+#' @export
+#'
+#' @keywords internal
+#'
+enableStartupMessages <- function() {
+    if (isTRUE(as.logical(base::getOption("rpact.startup.message.enabled")))) {
+        return(invisible())
+    }
+
+    base::options("rpact.startup.message.enabled" = TRUE)
+    saveOptions()
+}
+
+
+#'
+#' @title
+#' Check Installation Qualification Status
+#'
+#' @description
+#' This function checks whether the installation qualification for the `rpact` package
+#' has been completed. If not, it provides a message prompting the user to run the
+#' `testPackage()` function to perform the qualification.
+#'
+#' @param showMessage A logical value indicating whether to display a message if the
+#' installation qualification has not been completed. Default is \code{TRUE}.
+#'
+#' @details
+#' The installation qualification is a critical step in ensuring that the `rpact` package
+#' is correctly installed and validated for use in GxP-relevant environments. This function
+#' verifies the qualification status and informs the user if further action is required.
+#'
+#' @return
+#' Invisibly returns \code{TRUE} if the installation qualification has been completed,
+#' otherwise returns \code{FALSE}.
+#'
+#' @examples
+#' \dontrun{
+#' checkInstallationQualificationStatus()
+#' }
+#'
+#' @export
+#'
+#' @keywords internal
+#'
+checkInstallationQualificationStatus <- function(showMessage = TRUE) {
+    if (isTRUE(.installationQualificationDone())) {
+        return(invisible(TRUE))
+    }
+
+    if (!isTRUE(showMessage)) {
+        return(invisible(FALSE))
+    }
+
+    message(
+        "Installation qualification for rpact ", .getPackageVersionString(),
+        " has not yet been performed. Please run testPackage() ",
+        "before using the package in GxP relevant environments."
+    )
+    return(invisible(FALSE))
+}
+
 #'
 #' @title
 #' Get System Identifier
@@ -718,6 +899,21 @@ setupPackageTests <- function(token, secret) {
     )
 }
 
+.getExistingTestResultFiles <- function(path) {
+    .assertIsSingleCharacter(path, "path", naAllowed = FALSE)
+    subDir <- file.path(path, "rpact-tests")
+    if (dir.exists(subDir)) {
+        path <- c(path, subDir)
+    }
+    resultFiles <- list.files(
+        path = path,
+        pattern = "^testthat\\.Rout(\\.fail)?$",
+        recursive = FALSE,
+        full.names = TRUE
+    )
+    return(resultFiles)
+}
+
 #' @title
 #' Test and Validate the rpact Package Installation
 #'
@@ -765,7 +961,7 @@ setupPackageTests <- function(token, secret) {
 #' members of the rpact user group as part of the validation documentation.
 #' For more information, see vignette \href{https://www.rpact.org/vignettes/utilities/rpact_installation_qualification/}{rpact_installation_qualification}.
 #'
-#' @return Invisibly returns the value of \code{completeUnitTestSetEnabled}.
+#' @return Invisibly returns an \code{\link[=InstallationQualificationResult]{InstallationQualificationResult}}) object.
 #'
 #' @references For more information, please visit: <https://www.rpact.org/vignettes/utilities/rpact_installation_qualification/>
 #'
@@ -791,7 +987,8 @@ setupPackageTests <- function(token, secret) {
 #'
 #' @export
 #'
-testPackage <- function(outDir = ".",
+testPackage <- function(
+        outDir = ".",
         ...,
         completeUnitTestSetEnabled = TRUE,
         connection = list(token = NULL, secret = NULL),
@@ -884,9 +1081,12 @@ testPackage <- function(outDir = ".",
         )
     }
     if (is.null(author) || length(author) != 1 || is.na(author)) {
+        author <- .getOptionalArgument("author", ...)
+    }
+    if (is.null(author) || length(author) != 1 || is.na(author) || nchar(trimws(author)) == 0) {
         author <- "RPACT"
     }
-
+    
     downloadOnlyModeEnabled <- is.na(testFileDirectory) &&
         isTRUE(downloadTestsOnly) && isTRUE(credentialsAvailable)
 
@@ -926,9 +1126,9 @@ testPackage <- function(outDir = ".",
     }
 
     if (executionMode == "default") {
-        cat("Run a small subset of all tests. Please wait...\n")
-        cat("This is just a quick test (see comments below).\n")
-        cat("The entire test will take only some seconds.\n")
+        cat("Run a small subset of the available rpact unit tests. Please wait...\n")
+        cat("This is just a quick test for demonstration purposes.\n")
+        cat("The test will take about a minute.\n")
     } else if (executionMode == "downloadOnly") {
         cat("The unit test files are only downloaded and not executed.\n")
     } else if (executionMode %in% c("downloadAndRunTests", "runTestsInTestFileDirectory")) {
@@ -940,18 +1140,13 @@ testPackage <- function(outDir = ".",
                 sep = ""
             )
         } else {
-            cat("Run a subset of all tests. Please wait...\n")
+            cat("Run a small subset of the available rpact unit tests. Please wait...\n")
             cat("This is just a quick test, i.e., all time consuming tests will be skipped.\n")
-            cat("The entire test will take about a minute.\n")
+            cat("The test will take about a minute.\n")
         }
     }
 
-    oldResultFiles <- list.files(
-        path = outDir,
-        pattern = "^testthat\\.Rout(\\.fail)?$",
-        recursive = TRUE,
-        full.names = TRUE
-    )
+    oldResultFiles <- .getExistingTestResultFiles(outDir)
     for (oldResultFile in oldResultFiles) {
         if (file.exists(oldResultFile)) {
             file.remove(oldResultFile)
@@ -982,7 +1177,7 @@ testPackage <- function(outDir = ".",
             connectionType = .getConnectionArgument(connection, "connectionType")
         )
         if (downloadOnlyModeEnabled) {
-            return(invisible())
+            return(invisible(NULL))
         }
     }
 
@@ -995,6 +1190,7 @@ testPackage <- function(outDir = ".",
         }
 
         markdownReportFileName <- "rpact_test_result_report.md"
+        testFileTargetDirectory <- gsub("\\\\", "/", testFileTargetDirectory)
         testthatCommands <- paste0(
             "\n",
             "library(testthat)\n",
@@ -1019,12 +1215,10 @@ testPackage <- function(outDir = ".",
         pkgName = pkgName
     )
 
-    newResultFiles <- list.files(
-        path = outDir,
-        pattern = "^testthat\\.Rout(\\.fail)?$",
-        recursive = TRUE,
-        full.names = TRUE
-    )
+    newResultFiles <- .getExistingTestResultFiles(outDir)
+    if (length(newResultFiles) == 0) {
+        newResultFiles <- .getExistingTestResultFiles(testFileTargetDirectory)
+    }
 
     resultDir <- file.path(outDir, paste0(pkgName, "-tests"))
     if (!dir.exists(resultDir)) {
@@ -1047,30 +1241,44 @@ testPackage <- function(outDir = ".",
         endTime = endTime, runtimeUnits = "auto"
     ), ".\n", sep = "")
 
-    reportFileName <- NULL
-    if (reportType != "Rout" && !is.null(markdownReportFileName) &&
-            file.exists(file.path(testFileTargetDirectory, markdownReportFileName))) {
-        reportFileName <- character()
+    reportFileNames <- NULL
+    if (reportType != "Rout" && !is.null(markdownReportFileName)) {
+        reportFileNames <- character()
+
+        if (keepSourceFiles && file.exists(file.path(testFileTargetDirectory, markdownReportFileName))) {
+            reportFileNames <- c(reportFileNames, markdownReportFileName)
+        }
+
         reportFileNameHtml <- sub("\\.md$", ".html", markdownReportFileName)
         if (file.exists(file.path(testFileTargetDirectory, reportFileNameHtml))) {
-            reportFileName <- c(reportFileName, reportFileNameHtml)
+            reportFileNames <- c(reportFileNames, reportFileNameHtml)
         }
+
         reportFileNamePdf <- sub("\\.md$", ".pdf", markdownReportFileName)
         if (file.exists(file.path(testFileTargetDirectory, reportFileNamePdf))) {
-            reportFileName <- c(reportFileName, reportFileNamePdf)
+            reportFileNames <- c(reportFileNames, reportFileNamePdf)
         }
-        if (length(reportFileName) == 0) {
-            reportFileName <- markdownReportFileName
+
+        if (length(reportFileNames) > 0) {
+            file.copy(file.path(testFileTargetDirectory, reportFileNames), resultDir)
         }
     }
 
     minNumberOfExpectedTests <- .getMinNumberOfExpectedTests()
+    totalNumberOfTests <- NA_integer_
+    numberOfFailedTests <- 0
+    numberOfSkippedTests <- 0
     resultOuputFile <- "testthat.Rout"
     inputFileName <- file.path(resultDir, resultOuputFile)
+    resultMessage <- NA_character_
+    statusMessage <- NA_character_
+    status <- "incomplete"
     if (file.exists(inputFileName)) {
         fileContent <- base::readChar(inputFileName, file.info(inputFileName)$size)
         totalNumberOfTests <- .getTestthatResultNumberOfTests(fileContent)
         if (completeUnitTestSetEnabled && minNumberOfExpectedTests <= totalNumberOfTests) {
+            statusMessage <- "Installation qualification successfully completed"
+            status <- "success"
             .setSystemIdentifier()
             cat("All unit tests were completed successfully, i.e., the installation \n",
                 "qualification was successful.\n",
@@ -1079,29 +1287,25 @@ testPackage <- function(outDir = ".",
         } else {
             cat("Unit tests were completed successfully.\n")
             if (totalNumberOfTests < minNumberOfExpectedTests) {
-                cat("Only a subset of the ", minNumberOfExpectedTests, "
-					available rpact unit tests were executed.\n", sep = "")
+                cat("Only a subset of the ", minNumberOfExpectedTests,
+                    " available rpact unit tests were executed.\n",
+                    sep = ""
+                )
                 cat("This means the package is not yet validated for use in GxP-compliant settings.\n")
+                statusMessage <- "Installation qualification not completed (only a subset of tests executed)"
             }
         }
         cat("\n")
 
         cat("Results:\n")
-        cat(.getTestthatResultLine(fileContent), "\n")
+        resultMessage <- .getTestthatResultLine(fileContent)
+        cat(resultMessage, "\n")
         cat("\n")
-        cat("Test results were written to directory \n")
-        if (!is.null(reportFileName)) {
-            cat("'", testFileTargetDirectory, "' (see file(s) ",
-                .arrayToString(sQuote(reportFileName), mode = "and"), ")\n",
-                sep = ""
-            )
-        } else {
-            cat("'", resultDir, "' (see file ", sQuote(resultOuputFile), ")\n", sep = "")
-        }
-        skipped <- .getTestthatResultNumberOfSkippedTests(fileContent)
-        if (skipped > 0) {
+        .showResultsWereWrittenToDirectoryMessage(resultDir, reportFileNames, resultOuputFile)
+        numberOfSkippedTests <- .getTestthatResultNumberOfSkippedTests(fileContent)
+        if (numberOfSkippedTests > 0) {
             cat("-------------------------------------------------------------------------\n")
-            cat("Note that ", skipped, " tests were skipped; ",
+            cat("Note that ", numberOfSkippedTests, " tests were skipped; ",
                 "a possible reason may be that expected \n",
                 "error messages could not be tested ",
                 "because of local translation.\n",
@@ -1117,34 +1321,36 @@ testPackage <- function(outDir = ".",
         )
     } else {
         inputFileName <- file.path(resultDir, "testthat.Rout.fail")
+        status <- "failed"
         if (file.exists(inputFileName)) {
             fileContent <- base::readChar(inputFileName, file.info(inputFileName)$size)
             numberOfFailedTests <- .getTestthatResultNumberOfFailures(fileContent)
             if (completeUnitTestSetEnabled) {
                 if (numberOfFailedTests > 0) {
                     cat(numberOfFailedTests,
-                        " unit tests failed, i.e., the installation qualification was not successful.\n",
+                        " unit test", ifelse(numberOfFailedTests == 1, "", "s"),
+                        " failed, i.e., the installation qualification was not successful.\n",
                         sep = ""
                     )
+                    statusMessage <- paste0("Installation qualification was not successful (", numberOfFailedTests, " failures)")
                 } else {
                     cat("Unexpected failures, i.e., the installation qualification was not successful.\n")
+                    statusMessage <- "Installation qualification was not successful (unexpected failures)"
                 }
             } else {
-                cat(numberOfFailedTests, " unit tests failed :(\n", sep = "")
-            }
-            cat("Results:\n")
-            cat(.getTestthatResultLine(fileContent), "\n")
-            cat("Test results were written to directory ")
-            if (!is.null(reportFileName)) {
-                cat("'", testFileTargetDirectory, "' (see file(s) ",
-                    .arrayToString(sQuote(reportFileName), mode = "and"), ")\n",
+                cat(numberOfFailedTests, " unit test",
+                    ifelse(numberOfFailedTests == 1, "", "s"), " failed :(\n",
                     sep = ""
                 )
-            } else {
-                cat("'", resultDir, "' (see file ", sQuote(resultOuputFile), ")\n", sep = "")
+                statusMessage <- paste0("Installation qualification was not successful (subset with ", numberOfFailedTests, " failures)")
             }
+            cat("Results:\n")
+            resultMessage <- .getTestthatResultLine(fileContent)
+            cat(resultMessage, "\n")
+            .showResultsWereWrittenToDirectoryMessage(resultDir, reportFileNames, resultOuputFile)
         } else {
             cat("No test results found in directory '", resultDir, "'\n", sep = "")
+            statusMessage <- "Installation qualification was not successful (no test results found)"
         }
     }
     if (!credentialsAvailable) {
@@ -1152,13 +1358,137 @@ testPackage <- function(outDir = ".",
         cat("Note that only a small subset of all available unit tests were executed.\n")
         cat("You need a personal 'token' and 'secret' to perform all unit tests.\n")
         cat("You can find these data in the appendix of the validation documentation \n")
-        cat("licensed for your company/organization.\n")
+        cat("licensed for your company/organization or at https://connect.rpact.com.\n")
     } else if (!completeUnitTestSetEnabled) {
         cat("Note that only a small subset of all available unit tests were executed.\n")
         cat("Use testPackage(completeUnitTestSetEnabled = TRUE) to perform all unit tests.\n")
     }
 
-    invisible(.isCompleteUnitTestSetEnabled())
+    result <- list(
+        completeUnitTestSetEnabled = completeUnitTestSetEnabled,
+        testFileDirectory = testFileDirectory,
+        testFileTargetDirectory = testFileTargetDirectory,
+        reportType = reportType,
+        executionMode = executionMode,
+        scope = scope,
+        resultDir = resultDir,
+        resultOuputFile = resultOuputFile,
+        reportFileNames = reportFileNames,
+        minNumberOfExpectedTests = minNumberOfExpectedTests,
+        totalNumberOfTests = totalNumberOfTests,
+        numberOfFailedTests = numberOfFailedTests,
+        numberOfSkippedTests = numberOfSkippedTests,
+        resultMessage = resultMessage,
+        statusMessage = statusMessage,
+        status = status
+    )
+
+    result <- structure(result, class = "InstallationQualificationResult")
+
+    return(invisible(result))
+}
+
+#' 
+#' @title 
+#' Installation Qualification Result Object
+#'
+#' @description 
+#' This object represents the structured result of a full or partial
+#' installation qualification test execution. It includes metadata about
+#' the executed test suite, paths used, summary statistics, and status
+#' messages.
+#'
+#' @details 
+#' The object is returned by the function \code{\link{testPackage}} and
+#' is of class \code{InstallationQualificationResult}.
+#'
+#' @format An S3 object of class \code{InstallationQualificationResult} with the following elements:
+#' \describe{
+#'   \item{completeUnitTestSetEnabled}{Logical indicating whether the full test set was enabled}
+#'   \item{testFileDirectory}{Directory containing test scripts}
+#'   \item{testFileTargetDirectory}{Directory to which tests are copied or linked}
+#'   \item{reportType}{Report type selected (\code{"compact"}, \code{"detailed"}, or \code{"Rout"})}
+#'   \item{executionMode}{Execution mode (\code{"default"}, \code{"downloadOnly"}, 
+#'        \code{"downloadAndRunTests"}, or \code{"runTestsInTestFileDirectory"})}
+#'   \item{scope}{Scope of the qualification (`"basic"`, `"devel"`, `"both"`, `"internet"`, or `"all"`)}
+#'   \item{resultDir}{Directory where the result reports are stored}
+#'   \item{resultOuputFile}{Main output report filename}
+#'   \item{reportFileNames}{Vector of report files generated}
+#'   \item{minNumberOfExpectedTests}{Minimum number of expected tests}
+#'   \item{totalNumberOfTests}{Number of tests actually run}
+#'   \item{numberOfFailedTests}{Number of failed tests}
+#'   \item{numberOfSkippedTests}{Number of skipped tests}
+#'   \item{resultMessage}{Message summarizing the result}
+#'   \item{statusMessage}{Detailed status message}
+#'   \item{status}{Overall result status (\code{"success"}, \code{"incomplete"}, or \code{"failed"})}
+#' }
+#'
+#' @name InstallationQualificationResult
+#' @keywords internal
+#' @seealso \code{\link{testPackage}}
+#' @docType class
+#' @aliases InstallationQualificationResult-class
+#' 
+NULL
+
+#' 
+#' @title 
+#' Print Installation Qualification Result
+#'
+#' @description
+#' This function prints the details of an `InstallationQualificationResult` object in a user-friendly format.
+#'
+#' @param x An object of class `InstallationQualificationResult` containing the results of the installation qualification.
+#' @param ... Additional arguments passed to or from other methods.
+#'
+#' @details
+#' The function displays the result message, followed by the parameters and their values. It skips parameters with `NULL` or `NA` values.
+#'
+#' @return
+#' This function does not return a value. It is called for its side effects of printing the result.
+#'
+#' @examples
+#' \dontrun{
+#' result <- testPackage()
+#' print(result)
+#' }
+#' 
+#' @keywords internal
+#'
+#' @export
+#' 
+print.InstallationQualificationResult <- function(x, ...) {
+    cat("Installation Qualification Result:\n")
+    cat(x$resultMessage, "\n\n")
+    cat("Parameters:\n")
+    paramNames <- names(x)
+    paramNames <- paramNames[!grepl("resultMessage", paramNames)]
+    for (paramName in paramNames) {
+        paramValue <- x[[paramName]]
+        if (is.null(paramValue) || all(is.na(paramValue))) {
+            next
+        }
+
+        if (is.character(paramValue)) {
+            if (grepl("Dir(ectory)?$", paramName)) {
+                paramValue <- gsub("\\\\", "/", paramValue)
+            }
+            paramValue <- sQuote(paramValue)
+        }
+        cat("  ", paramName, ": ", .arrayToString(paramValue), "\n", sep = "")
+    }
+}
+
+.showResultsWereWrittenToDirectoryMessage <- function(resultDir, reportFileName, resultOuputFile) {
+    cat("Test results were written to directory \n")
+    if (!is.null(reportFileName)) {
+        cat("'", resultDir, "' (see file", ifelse(length(reportFileName) == 1, "", "s"), " ",
+            .arrayToString(sQuote(reportFileName), mode = "and"), ")\n",
+            sep = ""
+        )
+    } else {
+        cat("'", resultDir, "' (see file ", sQuote(resultOuputFile), ")\n", sep = "")
+    }
 }
 
 .testInstalledPackage <- function(testFileDirectory, ..., pkgName = "rpact", Ropts = character()) {
@@ -1186,7 +1516,7 @@ testPackage <- function(outDir = ".",
             shQuote(outfile)
         )
         cmd <- if (.Platform$OS.type == "windows") paste(cmd, "LANGUAGE=C") else paste("LANGUAGE=C", cmd)
-        res <- system(cmd)
+        res <- base::system(cmd)
         if (res) {
             file.rename(outfile, paste(outfile, "fail", sep = "."))
             return(invisible(1L))
@@ -1515,12 +1845,12 @@ MarkdownReporter <- R6::R6Class(
 
             resultStatusIcon <-
                 if (failureEnabled) {
-                        private$COLORS$FAILURE$unicode
-                    } else if (warningEnabled) {
-                        private$COLORS$WARNING$unicode
-                    } else {
-                        private$COLORS$SUCCESS$unicode
-                    }
+                    private$COLORS$FAILURE$unicode
+                } else if (warningEnabled) {
+                    private$COLORS$WARNING$unicode
+                } else {
+                    private$COLORS$SUCCESS$unicode
+                }
             if (self$outputSize == "detailed" || failureEnabled ||
                     (warningEnabled && self$addWarningDetailsToReport)) {
                 self$log(
