@@ -13,15 +13,23 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7126 $
-## |  Last changed: $Date: 2023-06-23 14:26:39 +0200 (Fr, 23 Jun 2023) $
-## |  Last changed by: $Author: pahlke $
-## |
 
 #' @include class_simulation_results.R
 #' @include f_core_utilities.R
 NULL
 
+.warnInCaseOfDefinedPiValue <- function(designPlan, piValueName) {
+    piValue <- designPlan[[piValueName]]
+    if (!is.null(piValue) && !is.na(piValue) && length(piValue) > 0) {
+        designPlan$.setParameterType(piValueName, C_PARAM_NOT_APPLICABLE)
+        warning("'pi2' (", .arrayToString(piValue), ") will be ignored ",
+            "because piecewise exponential survival function is enabled",
+            call. = FALSE
+        )
+        designPlan[[piValueName]] <- NA_real_
+    }
+}
+
 .isLambdaBasedSimulationEnabled <- function(pwsTimeObject) {
     if (!pwsTimeObject$.isLambdaBased()) {
         return(FALSE)
@@ -148,7 +156,7 @@ NULL
 #' \code{conditionalPower},
 #' \code{thetaH0},
 #' \code{plannedEvents},
-#' \code{eventsPerStage},
+#' \code{singleEventsPerStage},
 #' \code{minNumberOfEventsPerStage},
 #' \code{maxNumberOfEventsPerStage},
 #' \code{allocationRatioPlanned},
@@ -189,7 +197,7 @@ NULL
 #'         in treatment group 1.
 #'   \item \code{eventsPerStage2}: The observed number of events per stage
 #'         in treatment group 2.
-#'   \item \code{eventsPerStage}: The observed number of events per stage
+#'   \item \code{singleEventsPerStage}: The observed number of events per stage
 #'         in both treatment groups.
 #'   \item \code{rejectPerStage}: 1 if null hypothesis can be rejected, 0 otherwise.
 #'   \item \code{futilityPerStage}: 1 if study should be stopped for futility, 0 otherwise.
@@ -212,27 +220,26 @@ NULL
 #' \code{\link[=getRawData]{getRawData()}} can be used to get the simulated raw data from the
 #' object as \code{\link[base]{data.frame}}. Note that \code{getSimulationSurvival()}
 #' must called before with \code{maxNumberOfRawDatasetsPerStage} > 0.
-#' The data frame contains the following columns:
-#' \enumerate{
-#'   \item \code{iterationNumber}: The number of the simulation iteration.
-#'   \item \code{stopStage}: The stage of stopping.
-#'   \item \code{subjectId}: The subject id (increasing number 1, 2, 3, ...)
-#'   \item \code{accrualTime}: The accrual time, i.e., the time when the subject entered the trial.
-#'   \item \code{treatmentGroup}: The treatment group number (1 or 2).
-#'   \item \code{survivalTime}: The survival time of the subject.
-#'   \item \code{dropoutTime}: The dropout time of the subject (may be \code{NA}).
-#'   \item \code{observationTime}: The specific observation time.
-#'   \item \code{timeUnderObservation}: The time under observation is defined as follows:\cr
-#'         if (event == TRUE) {\cr
-#'             timeUnderObservation <- survivalTime;\cr
-#'         } else if (dropoutEvent == TRUE) {\cr
-#'             timeUnderObservation <- dropoutTime;\cr
-#'         } else {\cr
-#'             timeUnderObservation <- observationTime - accrualTime;\cr
-#'         }
-#'   \item \code{event}: \code{TRUE} if an event occurred; \code{FALSE} otherwise.
-#'   \item \code{dropoutEvent}: \code{TRUE} if an dropout event occurred; \code{FALSE} otherwise.
-#' }
+#' 
+#' **What `maxNumberOfRawDatasetsPerStage` does**
+#' 
+#' When `maxNumberOfRawDatasetsPerStage = 0` (the default), simulations run as usual but *no* 
+#' patient-level ("raw") data are kept - only summary results.
+#' 
+#' If you set `maxNumberOfRawDatasetsPerStage > 0`, rpact will **save up to that many 
+#' full patient-level datasets *per stage*** (i.e., per interim/final look). 
+#' Each saved dataset corresponds to one simulated iteration and contains all 
+#' subject-wise records accrued up to the stage at which that iteration stopped. 
+#' You can later retrieve these datasets with \code{\link[=getRawData]{getRawData()}}.
+#' 
+#' **Why "max" and not `numberOfRawDatasetsPerStage`?**
+#' 
+#' The value is an *upper bound per stage*, not a fixed count. The actual number of datasets stored can be smaller because:
+#' 
+#' - Some iterations stop early (e.g., at stage 1), so later stages receive fewer datasets.
+#' - The simulation might finish before reaching the cap due to other stopping or iteration limits.
+#' 
+#' As a result, the number specified is the **maximum possible** datasets saved *per stage*, not the exact number.
 #'
 #' @template return_object_simulation_results
 #' @template how_to_get_help_for_generics
@@ -243,7 +250,7 @@ NULL
 #'
 getSimulationSurvival <- function(design = NULL, ...,
         thetaH0 = 1, # C_THETA_H0_SURVIVAL_DEFAULT
-        directionUpper = TRUE, # C_DIRECTION_UPPER_DEFAULT
+        directionUpper = NA, # C_DIRECTION_UPPER_DEFAULT
         pi1 = NA_real_,
         pi2 = NA_real_,
         lambda1 = NA_real_,
@@ -292,39 +299,59 @@ getSimulationSurvival <- function(design = NULL, ...,
             ignore = "showStatistics", ...
         )
         .warnInCaseOfTwoSidedPowerArgument(...)
+        design <- .resetPipeOperatorQueue(design)
     }
 
-    .assertIsSingleLogical(directionUpper, "directionUpper")
+    directionUpper <- .assertIsValidDirectionUpper(directionUpper,
+        design,
+        objectType = "power", userFunctionCallEnabled = TRUE
+    )
     .assertIsSingleNumber(thetaH0, "thetaH0")
-    .assertIsInOpenInterval(thetaH0, "thetaH0", 0, NULL, naAllowed = TRUE)
+    .assertIsInOpenInterval(thetaH0, "thetaH0", lower = 0, upper = NULL, naAllowed = TRUE)
     .assertIsNumericVector(minNumberOfEventsPerStage, "minNumberOfEventsPerStage", naAllowed = TRUE)
     .assertIsNumericVector(maxNumberOfEventsPerStage, "maxNumberOfEventsPerStage", naAllowed = TRUE)
     .assertIsSingleNumber(conditionalPower, "conditionalPower", naAllowed = TRUE)
-    .assertIsInOpenInterval(conditionalPower, "conditionalPower", 0, 1, naAllowed = TRUE)
+    .assertIsInOpenInterval(conditionalPower, "conditionalPower", 
+        lower = 0, upper = 1, naAllowed = TRUE)
     .assertIsSingleNumber(thetaH1, "thetaH1", naAllowed = TRUE)
-    .assertIsInOpenInterval(thetaH1, "thetaH1", 0, NULL, naAllowed = TRUE)
+    .assertIsInOpenInterval(thetaH1, "thetaH1", lower = 0, upper = NULL, naAllowed = TRUE)
     .assertIsSinglePositiveInteger(maxNumberOfIterations, "maxNumberOfIterations", validateType = FALSE)
     .assertIsSingleNumber(seed, "seed", naAllowed = TRUE)
     .assertIsNumericVector(lambda1, "lambda1", naAllowed = TRUE)
     .assertIsNumericVector(lambda2, "lambda2", naAllowed = TRUE)
-    .assertIsSinglePositiveInteger(maxNumberOfSubjects, "maxNumberOfSubjects",
-        validateType = FALSE, naAllowed = TRUE
-    )
+    .assertIsValidMaxNumberOfSubjects(maxNumberOfSubjects, naAllowed = TRUE)
     .assertIsIntegerVector(allocation1, "allocation1", validateType = FALSE)
     .assertIsIntegerVector(allocation2, "allocation2", validateType = FALSE)
     .assertIsInClosedInterval(allocation1, "allocation1", lower = 1L, upper = NULL)
     .assertIsInClosedInterval(allocation2, "allocation2", lower = 1L, upper = NULL)
+    .assertIsSingleNumber(dropoutTime, "dropoutTime", naAllowed = TRUE)
+    .assertIsSingleNumber(dropoutRate1, "dropoutRate1", naAllowed = TRUE)
+    .assertIsSingleNumber(dropoutRate2, "dropoutRate2", naAllowed = TRUE)
     .assertIsSingleLogical(longTimeSimulationAllowed, "longTimeSimulationAllowed")
     .assertIsSingleLogical(showStatistics, "showStatistics", naAllowed = FALSE)
     .assertIsValidPlannedSubjectsOrEvents(design, plannedEvents, parameterName = "plannedEvents")
 
+    if (!is.na(dropoutTime) && dropoutTime <= 0) {
+        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dropoutTime' (", dropoutTime, ") must be > 0", call. = FALSE)
+    }
+    if (dropoutRate1 < 0 || dropoutRate1 >= 1) {
+        stop(
+            C_EXCEPTION_TYPE_ARGUMENT_OUT_OF_BOUNDS,
+            "'dropoutRate1' (", dropoutRate1, ") is out of bounds [0; 1)"
+        )
+    }
+    if (dropoutRate2 < 0 || dropoutRate2 >= 1) {
+        stop(
+            C_EXCEPTION_TYPE_ARGUMENT_OUT_OF_BOUNDS,
+            "'dropoutRate2' (", dropoutRate2, ") is out of bounds [0; 1)"
+        )
+    }
     if (design$sided == 2) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
             "Only one-sided case is implemented for the survival simulation design"
         )
     }
-
     if (!all(is.na(lambda2)) && !all(is.na(lambda1)) &&
             length(lambda2) != length(lambda1) && length(lambda2) > 1) {
         stop(
@@ -332,7 +359,6 @@ getSimulationSurvival <- function(design = NULL, ...,
             ") must be equal to length of 'lambda1' (", length(lambda1), ")"
         )
     }
-
     if (all(is.na(lambda2)) && !all(is.na(lambda1))) {
         warning("'lambda1' (", .arrayToString(lambda1), ") will be ignored ",
             "because 'lambda2' (", .arrayToString(lambda2), ") is undefined",
@@ -340,7 +366,6 @@ getSimulationSurvival <- function(design = NULL, ...,
         )
         lambda1 <- NA_real_
     }
-
     if (!all(is.na(lambda2)) && is.list(piecewiseSurvivalTime)) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
@@ -348,7 +373,6 @@ getSimulationSurvival <- function(design = NULL, ...,
             "because 'lambda2' (", .arrayToString(lambda2), ") is defined separately"
         )
     }
-
     thetaH1 <- .ignoreParameterIfNotUsed(
         "thetaH1", thetaH1, design$kMax > 1,
         "design is fixed ('kMax' = 1)", "Assumed effect"
@@ -377,7 +401,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         endpoint = "survival", calcSubjectsFunctionEnabled = FALSE
     )
 
-    simulationResults <- SimulationResultsSurvival(design, showStatistics = showStatistics)
+    simulationResults <- SimulationResultsSurvival$new(design, showStatistics = showStatistics)
     if (!is.na(conditionalPower)) {
         if (design$kMax > 1) {
             if (any(maxNumberOfEventsPerStage - minNumberOfEventsPerStage < 0) &&
@@ -458,9 +482,17 @@ getSimulationSurvival <- function(design = NULL, ...,
 
     pwsTimeObject <- getPiecewiseSurvivalTime(
         piecewiseSurvivalTime = piecewiseSurvivalTime,
-        lambda2 = lambda2, lambda1 = lambda1, median1 = median1, median2 = median2,
-        hazardRatio = hazardRatio, pi1 = pi1, pi2 = pi2, eventTime = eventTime, kappa = kappa,
-        delayedResponseAllowed = TRUE, .pi1Default = C_PI_1_DEFAULT
+        lambda2 = lambda2,
+        lambda1 = lambda1,
+        median1 = median1,
+        median2 = median2,
+        hazardRatio = hazardRatio,
+        pi1 = pi1,
+        pi2 = pi2,
+        eventTime = eventTime,
+        kappa = kappa,
+        delayedResponseAllowed = TRUE,
+        .pi1Default = C_PI_1_DEFAULT
     )
 
     simulationResults$.piecewiseSurvivalTime <- pwsTimeObject
@@ -577,7 +609,7 @@ getSimulationSurvival <- function(design = NULL, ...,
     .setValueAndParameterType(simulationResults, "dropoutTime", dropoutTime, C_DROP_OUT_TIME_DEFAULT)
     .setValueAndParameterType(simulationResults, "thetaH0", thetaH0, C_THETA_H0_SURVIVAL_DEFAULT)
 
-    allocationFraction <- getFraction(allocation1 / allocation2)
+    allocationFraction <- .getFraction(allocation1 / allocation2)
     if (allocationFraction[1] != allocation1 || allocationFraction[2] != allocation2) {
         warning(sprintf(
             "allocation1 = %s and allocation2 = %s was replaced by allocation1 = %s and allocation2 = %s",
@@ -586,6 +618,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         allocation1 <- allocationFraction[1]
         allocation2 <- allocationFraction[2]
     }
+    .warnInCaseOfExtremeAllocationRatios(allocation1, allocation2)
 
     .setValueAndParameterType(simulationResults, "allocation1", allocation1, C_ALLOCATION_1_DEFAULT)
     .setValueAndParameterType(simulationResults, "allocation2", allocation2, C_ALLOCATION_2_DEFAULT)
@@ -614,54 +647,26 @@ getSimulationSurvival <- function(design = NULL, ...,
 
     phi <- -c(log(1 - dropoutRate1), log(1 - dropoutRate2)) / dropoutTime
 
-    densityIntervals <- accrualTime
-    if (length(accrualTime) > 1) {
-        densityIntervals[2:length(accrualTime)] <-
-            accrualTime[2:length(accrualTime)] - accrualTime[1:(length(accrualTime) - 1)]
-    }
-    densityVector <- accrualSetup$accrualIntensity / sum(densityIntervals * accrualSetup$accrualIntensity)
+    recruitmentTimes <- .generateRecruitmentTimes(
+        allocationRatioPlanned,
+        accrualTime,
+        accrualSetup$accrualIntensity
+    )$recruit
 
-    intensityReplications <- round(densityVector * densityIntervals * accrualSetup$maxNumberOfSubjects)
+    recruitmentTimes <- recruitmentTimes[1:accrualSetup$maxNumberOfSubjects]
 
-    if (all(intensityReplications > 0)) {
-        accrualTimeValue <- cumsum(rep(
-            1 / (densityVector * accrualSetup$maxNumberOfSubjects), intensityReplications
-        ))
-    } else {
-        accrualTimeValue <- cumsum(rep(
-            1 / (densityVector[1] * accrualSetup$maxNumberOfSubjects),
-            intensityReplications[1]
-        ))
-        if (length(accrualIntensity) > 1 && length(intensityReplications) > 1) {
-            for (i in 2:min(length(accrualIntensity), length(intensityReplications))) {
-                if (intensityReplications[i] > 0) {
-                    accrualTimeValue <- c(
-                        accrualTimeValue,
-                        accrualTime[i - 1] +
-                            cumsum(rep(
-                                1 / (densityVector[i] * accrualSetup$maxNumberOfSubjects),
-                                intensityReplications[i]
-                            ))
-                    )
-                }
-            }
+    # to force last value to be last accrualTime
+    recruitmentTimes[length(recruitmentTimes)] <- accrualTime[length(accrualTime)]
+
+    treatments <- c()
+    while (length(treatments) < accrualSetup$maxNumberOfSubjects) {
+        if (allocation1 > allocation2) {
+            treatments <- c(treatments, rep(c(1, 2), allocation2), rep(1, allocation1 - allocation2))
+        } else {
+            treatments <- c(treatments, rep(c(1, 2), allocation1), rep(2, allocation2 - allocation1))
         }
     }
-
-    accrualTimeValue <- accrualTimeValue[1:accrualSetup$maxNumberOfSubjects]
-
-    # to avoid last value to be NA_real_
-    i <- accrualSetup$maxNumberOfSubjects
-    while (is.na(accrualTimeValue[i])) {
-        accrualTimeValue[i] <- accrualTime[length(accrualTime)]
-        i <- i - 1
-    }
-
-    treatmentGroup <- rep(
-        c(rep(1, allocation1), rep(2, allocation2)),
-        ceiling(accrualSetup$maxNumberOfSubjects /
-            (allocation1 + allocation2))
-    )[1:accrualSetup$maxNumberOfSubjects]
+    treatments <- treatments[1:accrualSetup$maxNumberOfSubjects]
 
     if (.isTrialDesignFisher(design)) {
         alpha0Vec <- design$alpha0Vec
@@ -700,11 +705,11 @@ getSimulationSurvival <- function(design = NULL, ...,
     calcEventsFunctionR <- calcSubjectsFunctionList$calcSubjectsFunctionR
     calcEventsFunctionCpp <- calcSubjectsFunctionList$calcSubjectsFunctionCpp
 
-    resultData <- getSimulationSurvivalCpp(
+    resultData <- .getSimulationSurvivalCpp(
         designNumber                   = designNumber,
         kMax                           = design$kMax,
         sided                          = design$sided,
-        criticalValues                 = design$criticalValues,
+        criticalValues                 = .getCriticalValues(design),
         informationRates               = design$informationRates,
         conditionalPower               = conditionalPower,
         plannedEvents                  = plannedEvents,
@@ -713,8 +718,8 @@ getSimulationSurvival <- function(design = NULL, ...,
         maxNumberOfEventsPerStage      = maxNumberOfEventsPerStage,
         directionUpper                 = directionUpper,
         allocationRatioPlanned         = allocationRatioPlanned,
-        accrualTime                    = accrualTimeValue,
-        treatmentGroup                 = treatmentGroup,
+        accrualTime                    = recruitmentTimes,
+        treatmentGroup                 = treatments,
         thetaH0                        = thetaH0,
         futilityBounds                 = futilityBounds,
         alpha0Vec                      = alpha0Vec,
@@ -753,7 +758,8 @@ getSimulationSurvival <- function(design = NULL, ...,
     }
     simulationResults$iterations <- matrix(as.integer(overview$iterations), nrow = design$kMax)
     if (!is.null(overview$eventsPerStage)) {
-        simulationResults$eventsPerStage <- matrix(overview$eventsPerStage, nrow = design$kMax)
+        simulationResults$singleEventsPerStage <- matrix(overview$eventsPerStage, nrow = design$kMax)
+        .addDeprecatedFieldValues(simulationResults, "eventsPerStage", simulationResults$singleEventsPerStage)
     }
     simulationResults$eventsNotAchieved <- matrix(overview$eventsNotAchieved, nrow = design$kMax)
     if (any(simulationResults$eventsNotAchieved > 0)) {
@@ -794,7 +800,7 @@ getSimulationSurvival <- function(design = NULL, ...,
 
     if (design$kMax == 1) {
         simulationResults$.setParameterType("numberOfSubjects", C_PARAM_NOT_APPLICABLE)
-        simulationResults$.setParameterType("eventsPerStage", C_PARAM_NOT_APPLICABLE)
+        simulationResults$.setParameterType("singleEventsPerStage", C_PARAM_NOT_APPLICABLE)
     }
 
     if (design$kMax > 1) {
@@ -817,6 +823,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         simulationResults$futilityStop <- matrix(overview$futilityStop, nrow = design$kMax)[1, ]
         simulationResults$earlyStop <- simulationResults$futilityStop +
             simulationResults$overallReject - simulationResults$rejectPerStage[design$kMax, ]
+        simulationResults$.setParameterType("earlyStop", C_PARAM_GENERATED)
     } else {
         simulationResults$futilityStop <- rep(0, numberOfResults)
         simulationResults$earlyStop <- rep(0, numberOfResults)
@@ -834,25 +841,33 @@ getSimulationSurvival <- function(design = NULL, ...,
         numberOfSubjects[is.na(numberOfSubjects)] <- 0
         simulationResults$expectedNumberOfSubjects <- diag(t(numberOfSubjects) %*% pStop)
 
-        if (!is.null(simulationResults$eventsPerStage) &&
-                nrow(simulationResults$eventsPerStage) > 0 &&
-                ncol(simulationResults$eventsPerStage) > 0) {
-            simulationResults$overallEventsPerStage <- .convertStageWiseToOverallValues(
-                simulationResults$eventsPerStage
+        if (!is.null(simulationResults$singleEventsPerStage) &&
+                nrow(simulationResults$singleEventsPerStage) > 0 &&
+                ncol(simulationResults$singleEventsPerStage) > 0) {
+            simulationResults$cumulativeEventsPerStage <- .convertStageWiseToOverallValues(
+                simulationResults$singleEventsPerStage
+            )
+            simulationResults$.setParameterType("cumulativeEventsPerStage", C_PARAM_GENERATED)
+            .addDeprecatedFieldValues(
+                simulationResults,
+                "overallEventsPerStage", simulationResults$cumulativeEventsPerStage
             )
-            simulationResults$.setParameterType("overallEventsPerStage", C_PARAM_GENERATED)
             simulationResults$expectedNumberOfEvents <-
-                diag(t(simulationResults$overallEventsPerStage) %*% pStop)
+                diag(t(simulationResults$cumulativeEventsPerStage) %*% pStop)
         }
     } else {
         simulationResults$expectedNumberOfSubjects <-
             as.numeric(simulationResults$numberOfSubjects)
-        if (!is.null(simulationResults$eventsPerStage) &&
-                nrow(simulationResults$eventsPerStage) > 0 &&
-                ncol(simulationResults$eventsPerStage) > 0) {
-            simulationResults$overallEventsPerStage <- simulationResults$eventsPerStage
+        if (!is.null(simulationResults$singleEventsPerStage) &&
+                nrow(simulationResults$singleEventsPerStage) > 0 &&
+                ncol(simulationResults$singleEventsPerStage) > 0) {
+            simulationResults$cumulativeEventsPerStage <- simulationResults$singleEventsPerStage
+            .addDeprecatedFieldValues(
+                simulationResults,
+                "overallEventsPerStage", simulationResults$cumulativeEventsPerStage
+            )
             simulationResults$expectedNumberOfEvents <-
-                as.numeric(simulationResults$overallEventsPerStage)
+                as.numeric(simulationResults$cumulativeEventsPerStage)
         }
     }
     if (is.null(simulationResults$expectedNumberOfEvents) ||
@@ -893,7 +908,7 @@ getSimulationSurvival <- function(design = NULL, ...,
             pi2 = numeric(0),
             subjectId = numeric(0),
             accrualTime = numeric(0),
-            treatmentGroup = numeric(0),
+            treatments = numeric(0),
             survivalTime = numeric(0),
             dropoutTime = numeric(0),
             observationTime = numeric(0),
